@@ -253,24 +253,32 @@ OC.L10N.register(
     "Saved" : "Bewaar",
     "Copy link" : "Kopieer skakel",
     "Dismiss" : "Ontslaan",
+    "Back" : "Terug",
     "Favorite" : "Gunsteling",
     "Remove from favorites" : "Verwyder uit gunstelinge",
     "Add to favorites" : "Voeg by gunstelinge",
     "Loading" : "Laai tans..",
     "Groups" : "Groepe",
+    "Settings" : "Instellings",
     "Password protect" : "Beskerm met 'n wagwoord",
-    "Back" : "Terug",
     "Close" : "Sluit",
     "Reply" : "Antwoord",
+    "Remove" : "Verwyder",
     "Today" : "Vandag",
     "Yesterday" : "Gister",
+    "Save" : "Stoor",
+    "Password" : "Wagwoord",
+    "Login" : "Teken aan",
+    "Nickname" : "Bynaam",
+    "Client ID" : "Kliënt-ID",
     "Chat" : "Klets",
-    "Settings" : "Instellings",
     "Edit" : "Wysig",
+    "Keyboard shortcuts" : "Sneltoetse",
+    "Search" : "Soek",
     "Share link" : "Deelskakel",
     "Enter a password" : "Gee ’n wagwoord",
+    "Default" : "Verstek",
     "The password is wrong. Try again." : "Die wagwoord is verkeerd. Probeer weer.",
-    "Password" : "Wagwoord",
     "Android app" : "Android-toep",
     "iOS app" : "iOS-toep",
     "Copy" : "Kopieer",
