@@ -6,6 +6,7 @@ OC.L10N.register(
     "You left the call" : "لقد قمت بمغادرة المكالمة",
     "Click the button below to join." : "اضغط على الزر للانضمام.",
     "Open settings" : "فتح الإعدادات",
+    "Messages" : "الرسائل",
     "Andorra" : "أندورا",
     "United Arab Emirates" : "الإمارات العربية المتحدة",
     "Afghanistan" : "أفغانستان",
@@ -141,6 +142,7 @@ OC.L10N.register(
     "Dismiss" : "تراجع",
     "Mute audio" : "كتم الصوت",
     "Disable video" : "تعطيل الفيديو",
+    "Back" : "العودة",
     "You" : "أنت",
     "Drop your files to upload" : "افلت الملفات لرفعها",
     "Favorite" : "المفضلة",
@@ -150,31 +152,40 @@ OC.L10N.register(
     "Add to favorites" : "أضفه إلى المفضلة",
     "Loading" : "Loading",
     "Groups" : "الفِرَق",
+    "Settings" : "الإعدادات",
     "Password protect" : "حماية كلمة السر",
-    "Back" : "العودة",
     "Close" : "إغلاق",
     "Conversation name" : "اسم المحادثة",
+    "Camera" : "الكاميرا",
     "Reply" : "رد",
+    "Remove" : "حذف",
     "Today" : "اليوم",
     "Yesterday" : "البارحة",
     "Send message" : "أرسل رسالة",
+    "Enabled" : "مفعلة",
+    "Save" : "حفظ",
+    "Password" : "الكلمة السرية",
+    "Login" : "الدخول",
+    "Nickname" : "كنية.\nلقب.",
     "No results" : "دون أية نتيجة",
     "Add users or groups" : "Add users or groups",
     "Participants" : "المشاركون",
     "Chat" : "الدردشة",
-    "Projects" : "المشاريع",
-    "Settings" : "الإعدادات",
     "Edit" : "تعديل",
+    "Keyboard shortcuts" : "إختصارات لوحة المفاتيح",
+    "Search" : "البحث",
     "Rename conversation" : "إعادة تسمية المحادثة",
     "Share link" : "مشاركة الرابط",
     "Password protection" : "الحماية بكلمة السر",
     "Enter a password" : "إدخِل كلمة سرية",
     "Grid view" : "عرض شبكي",
+    "Start a conversation" : "ابدأ محادثة",
+    "Default" : "افتراضي",
     "The password is wrong. Try again." : "كلمة المرور خاطئة. حاول مرة أخرى.",
-    "Password" : "الكلمة السرية",
     "Join conversations at any time, anywhere, on any device." : "انضم إلى المحادثات في أي وقت و من أي مكان و عبر أي جهاز",
     "Android app" : "تطبيق الأندرويد",
     "iOS app" : "تطبيق آي أواس",
+    "Projects" : "المشاريع",
     "Copy" : "أنسخ",
     "Copied!" : "تم نسخه !",
     "Not supported!" : "غير مدعوم!",
