@@ -43,6 +43,7 @@ OC.L10N.register(
     "Mute audio" : "Silenciar audiu",
     "Disable video" : "Deshabilitar videu",
     "Enable screensharing" : "Activar compartición de pantalla",
+    "Back" : "Atrás",
     "Screensharing requires the page to be loaded through HTTPS." : "La compartición de pantalla rique que les páxines carguen pente HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la to pantalla namái funciona con Firefox 52 o más mayor.",
     "Screensharing extension is required to share your screen." : "Ríquese la estensión de compartición de pantalla pa compartir la to pantalla",
@@ -55,28 +56,37 @@ OC.L10N.register(
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
+    "Settings" : "Settings",
     "Password protect" : "Protexer con contraseña",
-    "Back" : "Atrás",
     "Close" : "Zarrar",
     "Reply" : "Rempuesta",
+    "Remove" : "Desaniciar",
     "Today" : "Güei",
     "Yesterday" : "Ayeri",
+    "Enabled" : "Habilitar",
+    "Save" : "Guardar",
+    "Password" : "Password",
+    "API token" : "Pase d'API",
+    "Login" : "Aniciu de sesión",
+    "Nickname" : "Nomatu",
+    "Client ID" : "ID de veceru",
     "guest" : "invitáu",
     "No results" : "Ensin resultaos",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Settings",
     "Edit" : "Editar",
+    "Keyboard shortcuts" : "Atayos de tecláu",
+    "Search" : "Search",
     "Share link" : "Compartir enllaz",
     "Password protection" : "Password protection",
     "Enter a password" : "Introduz una contraseña",
     "Grid view" : "Vista de rexella",
+    "Default" : "Predetermináu",
     "Access to microphone & camera is only possible with HTTPS" : "L'accesu a la cámara y micrófonu namái ye posible con HTTPS",
     "Access to microphone & camera was denied" : "Ñegóse l'accesu a la cámara y micrófonu",
     "WebRTC is not supported in your browser" : "WebRTC nun ta sofitao nel to restolador",
     "Please use a different browser like Firefox or Chrome" : "Usa un restoador distintu como Firefox o Chrome, por favor",
     "Error while accessing microphone & camera" : "Fallu entrín s'accedia al micrófonu y cámara",
     "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
-    "Password" : "Password",
     "TURN server" : "Sirvidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El sirvidor TURN úsase pa unviar al proxy el tráficu de los participantes darrera de tornafueos.",
     "Android app" : "Aplicación p'Android",
