@@ -19,18 +19,25 @@ OC.L10N.register(
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "Grupe",
+    "Settings" : "Podešavanje",
     "Password protect" : "Zaštitita lozinkom",
     "Close" : "Zatvori",
     "Today" : "Danas",
     "Yesterday" : "Jučer",
+    "Enabled" : "Aktivirano",
+    "Save" : "Spremi",
+    "Password" : "Lozinka",
+    "Login" : "Login",
+    "Nickname" : "Nadimak",
     "guest" : "gost",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Podešavanje",
     "Edit" : "Izmjeni",
+    "Keyboard shortcuts" : "Tipkovni prečaci",
+    "Search" : "Search",
     "Share link" : "Podijelite vezu",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Password" : "Lozinka",
+    "Default" : "Zadano",
     "Android app" : "Android aplikacija",
     "iOS app" : "iOS aplikacija",
     "Copied!" : "Kopirano",
