@@ -127,6 +127,7 @@ OC.L10N.register(
     "Someone tried to request the password to access {file}" : "Nogen forsøgte at bede om adgangskoden til {file}",
     "Open settings" : "Indstillinger",
     "Conversations" : "Samtaler",
+    "Messages" : "Beskeder",
     "Andorra" : "Andorra",
     "Afghanistan" : "Afghanistan",
     "Albania" : "Albanien",
@@ -266,10 +267,8 @@ OC.L10N.register(
     "Error" : "Fejl",
     "Blocked" : "Blokeret",
     "Expired" : "Udløbet",
-    "Signaling server URL" : "Signalserver URL",
     "Validate SSL certificate" : "Godkend SSL certifikat",
     "Delete this server" : "Slet denne server",
-    "Signaling servers" : "Signaleringsservere",
     "Saved" : "Gemt",
     "Add a new server" : "Tilføj en ny server",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver bør eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
@@ -311,6 +310,7 @@ OC.L10N.register(
     "Enable video" : "Slå video til",
     "Screensharing options" : "Skærmdeling indstillinger",
     "Enable screensharing" : "Slå skærmdeling til",
+    "Back" : "Tilbage",
     "Screen sharing is not supported by your browser." : "Skærmdeling er ikke understøttet af din browser.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden er hentet over HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skærmdeling kræver at siden bliver vist gennem HTTPS.",
@@ -341,12 +341,9 @@ OC.L10N.register(
     "No search results" : "Ingen søgeresultater",
     "Groups" : "Grupper",
     "Circles" : "Cirkler",
-    "Default location for attachments" : "Standard-lokation for vedhæftninger",
+    "Settings" : "Indstillinger",
     "Groups and circles" : "Grupper og cirkler",
     "Other sources" : "Andre kilder",
-    "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger",
-    "Invalid path selected" : "Ugyldig filsti valgt",
-    "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
     "Creating your conversation" : "Opret din samtale",
     "All set" : "Samtalen er klar",
     "Copy conversation link" : "Kopier samtalelink",
@@ -355,7 +352,6 @@ OC.L10N.register(
     "Create a new group conversation" : "Opret en ny gruppesamtale",
     "Password protect" : "Beskyt med adgangskode",
     "Add participants" : "Tilføj deltagere",
-    "Back" : "Tilbage",
     "Create conversation" : "Opret samtale",
     "Close" : "Luk",
     "Choose a password" : "Vælg en adgangskode",
@@ -365,7 +361,9 @@ OC.L10N.register(
     "Allow guests to join via link " : "Tillad gæster at deltage via link",
     "You are currently waiting in the lobby" : "Du venter nu i lobbyen",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du venter nu i lobbyen. Dette møde er planlagt til {startTime}",
+    "Camera" : "Kamera",
     "Reply" : "Besvar",
+    "Remove" : "Fjern",
     "[Unknown username]" : "[Ukendt brugernavn]",
     "Today" : "I dag",
     "Yesterday" : "I går",
@@ -375,6 +373,14 @@ OC.L10N.register(
     "Share from Files" : "Del fra Filer",
     "Send message" : "Send besked",
     "File to share" : "Vælg fil til deling",
+    "Invalid path selected" : "Ugyldig filsti valgt",
+    "Enabled" : "Aktiveret",
+    "Save" : "Gem",
+    "Password" : "Password",
+    "API token" : "API nøgle",
+    "Login" : "Login",
+    "Nickname" : "Kaldenavn",
+    "Client ID" : "Klient-ID",
     "moderator" : "moderator",
     "guest" : "Gæst",
     "Demote from moderator" : "Degrader fra moderator",
@@ -392,10 +398,11 @@ OC.L10N.register(
     "Participants" : "Deltagere",
     "An error occurred while fetching the participants" : "Kunne ikke hente listen over deltagere",
     "Chat" : "Chat",
-    "Projects" : "Projekter",
-    "Settings" : "Indstillinger",
     "Display name: " : "Vist navn:",
     "Edit" : "Rediger",
+    "Keyboard shortcuts" : "Tastaturgenveje",
+    "Search" : "Søg",
+    "Error while setting attachment folder" : "Fejl under indstilling af mappe til vedhæftninger",
     "Start call" : "Start opkald",
     "Go to file" : "Gå til fil",
     "Rename conversation" : "Omdøb samtale",
@@ -407,19 +414,20 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Forlad fuldskærmsvisning (f)",
     "Fullscreen (f)" : "Vis i fuldskærm (f)",
     "Grid view" : "Grid visning",
+    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
+    "Start a conversation" : "Start en samtale",
     "Message without mention" : "Besked som ikke nævner nogen",
     "Mention myself" : "Nævn mig selv",
     "Mention room" : "Nævn rum",
     "The conversation does not exist" : "Samtalen findes ikke",
     "Join a conversation or start a new one!" : "Deltag i en samtale eller start en ny!",
-    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
+    "Link to a conversation" : "Link til samtale",
     "Select conversation" : "Vælg samtale",
     "Join a conversation or start a new one" : "Deltag i en samtale eller start en ny",
-    "Say hi to your friends and colleagues!" : "Sig hej til dine venner og kollegaer.",
-    "Link to a conversation" : "Link til samtale",
     "Error while sharing file" : "Fejl ved deling af fil",
     "Error while uploading file" : "Fejl ved upload af fil",
     "Sending signaling message has failed." : "Kunne ikke sende signalerings-besked",
+    "Default" : "Standard",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Det virker som om du snakker mens lyden er slået fra, slå den til hvis du vil have at andre skal høre dig",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Dette tager lidt længere end forventet. Er medie-rettigheder allerede givet (eller nægtet)? Hvis ja så prøv at genstarte din browser, for lyd og video virker ikke lige nu",
     "Access to microphone & camera is only possible with HTTPS" : "Adgang til mikrofon og kamera er kun tilgængeligt over HTTPS",
@@ -430,10 +438,10 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Der opstod en fejl da vi prøvede at få adgang til din mikrofon og kamera",
     "This conversation is password-protected" : "Denne samtale er beskyttet af adgangskode",
     "The password is wrong. Try again." : "Passwordet er forkert. Prøv igen.",
-    "Password" : "Password",
     "Specify commands the users can use in chats" : "Definer kommandoer brugerne kan bruge i chats",
     "TURN server" : "TURN server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN serveren bliver brugt til at proxy trafikken fra deltagerne bagved en firewall.",
+    "Signaling servers" : "Signaleringsservere",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signaleringsserver kan eventuelt bruges i større installationer. Efterlad tom for at bruge intern signaleringsserver.",
     "%s Talk on your mobile devices" : "%s Talk på dine mobilenheder",
     "Join conversations at any time, anywhere, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
@@ -442,6 +450,7 @@ OC.L10N.register(
     "Enter name for a new conversation" : "Indtast navn på en ny samtale",
     "{name} (public)" : "{name} (offentlig)",
     "New conversation …" : "Ny samtale …",
+    "Projects" : "Projekter",
     "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Opkald med mere end 4 deltagere uden en ekstern signaleringsserver, kan deltagerne opleve problemer med forbindelsen og det kan skabe høj belastning på deltagernes enheder.",
     "Copy" : "Kopiér",
     "Copied!" : "Kopieret!",
@@ -504,6 +513,7 @@ OC.L10N.register(
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Kommandoer er en ny beta-feature i Nextcloud Talk. De tillader dig at køre scripts på din Nextcloud-server. Du kan definere dem vha vores kommandolinje-interface. Et eksempel på et lommeregner-script kan findes i vores <a {attributes}>dokumentation ↗</a>.",
     "Start calls" : "Start opkald",
     "Who can start a call?" : "Hvem kan starte et opkald?",
+    "Select a conversation to add to the project" : "Vælg en samtale for at tilføje den til projektet",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-server bruges som proxy for trafik fra deltagere som er bag en firewall.",
     "Join conversations at any time, any where, on any device." : "Deltag i samtaler når som helst, hvor som helst og på en hvilken som helst enhed.",
     "Contacts" : "Kontakter",
@@ -518,6 +528,9 @@ OC.L10N.register(
     "Add contacts" : "Tilføj kontakter",
     "Add contacts, groups or circles" : "Tilføj kontakter, grupper eller cirkler",
     "Add contacts or groups" : "Tilføj kontakter eller grupper",
-    "Add contacts or circles" : "Tilføj kontakter eller cirkler"
+    "Add contacts or circles" : "Tilføj kontakter eller cirkler",
+    "Signaling server URL" : "Signalserver URL",
+    "Default location for attachments" : "Standard-lokation for vedhæftninger",
+    "Select default location for attachments" : "Vælg standard-lokation for vedhæftninger"
 },
 "nplurals=2; plural=(n != 1);");
