@@ -22,6 +22,7 @@ OC.L10N.register(
     "A group call has started in {call}" : "A group call has started in {call}",
     "Open settings" : "Open settings",
     "Conversations" : "Conversations",
+    "Messages" : "Messages",
     "Invalid date, date format must be YYYY-MM-DD" : "Invalid date, date format must be YYYY-MM-DD",
     "Leave call" : "Leave call",
     "This conversation has ended" : "This conversation has ended",
@@ -72,6 +73,7 @@ OC.L10N.register(
     "Enable video" : "Enable video",
     "Screensharing options" : "Screensharing options",
     "Enable screensharing" : "Enable screensharing",
+    "Back" : "Back",
     "Screensharing requires the page to be loaded through HTTPS." : "Screensharing requires the page to be loaded through HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Sharing your screen only works with Firefox version 52 or newer.",
     "Screensharing extension is required to share your screen." : "Screensharing extension is required to share your screen.",
@@ -87,15 +89,24 @@ OC.L10N.register(
     "Loading" : "Loading",
     "Groups" : "Groups",
     "Circles" : "Circles",
+    "Settings" : "Settings",
     "Password protect" : "Password protect",
-    "Back" : "Back",
     "Close" : "Close",
     "Conversation name" : "Conversation name",
+    "Camera" : "Camera",
     "Reply" : "Reply",
+    "Remove" : "Remove",
     "Today" : "Today",
     "Yesterday" : "Yesterday",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "Send message",
+    "Enabled" : "Enabled",
+    "Save" : "Save",
+    "Password" : "Password",
+    "API token" : "API token",
+    "Login" : "Login",
+    "Nickname" : "Nickname",
+    "Client ID" : "Client ID",
     "moderator" : "moderator",
     "guest" : "guest",
     "Demote from moderator" : "Demote from moderator",
@@ -105,8 +116,9 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participants",
     "Chat" : "Chat",
-    "Settings" : "Settings",
     "Edit" : "Edit",
+    "Keyboard shortcuts" : "Keyboard shortcuts",
+    "Search" : "Search",
     "Rename conversation" : "Rename conversation",
     "Share link" : "Share link",
     "Password protection" : "Password protection",
@@ -114,7 +126,9 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Exit fullscreen (f)",
     "Fullscreen (f)" : "Fullscreen (f)",
     "Grid view" : "Grid view",
+    "Start a conversation" : "Start a conversation",
     "Join a conversation or start a new one" : "Join a conversation or start a new one",
+    "Default" : "Default",
     "Access to microphone & camera is only possible with HTTPS" : "Access to microphone & camera is only possible with HTTPS",
     "Please move your setup to HTTPS" : "Please move your setup to HTTPS",
     "Access to microphone & camera was denied" : "Access to microphone & camera was denied",
@@ -122,7 +136,6 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Please use a different browser like Firefox or Chrome",
     "Error while accessing microphone & camera" : "Error while accessing microphone & camera",
     "The password is wrong. Try again." : "The password is wrong. Try again.",
-    "Password" : "Password",
     "TURN server" : "TURN server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "The TURN server is used to proxy the traffic from participants behind a firewall.",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server.",
