@@ -263,6 +263,7 @@ OC.L10N.register(
     "Saved" : "Konservita",
     "Copy link" : "Kopii ligilon",
     "Dismiss" : "Preterpasi",
+    "Back" : "Antaŭen",
     "You" : "Vi",
     "Favorite" : "Pliŝatata",
     "Remove from favorites" : "Forigi el pliŝataĵoj",
@@ -270,24 +271,34 @@ OC.L10N.register(
     "Loading" : "Ŝargado",
     "Groups" : "Grupoj",
     "Circles" : "Rondoj",
+    "Settings" : "Agordoj",
     "Password protect" : "Protekti per pasvorto",
-    "Back" : "Antaŭen",
     "Close" : "Malfermi",
+    "Camera" : "Fotilo",
     "Reply" : "Respondi",
+    "Remove" : "Forigi",
     "Today" : "Hodiaŭ",
     "Yesterday" : "Hieraŭ",
+    "Enabled" : "Ŝaltita",
+    "Save" : "Konservi",
+    "Password" : "Pasvorto",
+    "API token" : "API-ĵetono",
+    "Login" : "Login",
+    "Nickname" : "Kromnomo",
+    "Client ID" : "Klientidentigilo",
     "guest" : "gasto",
     "No results" : "Neniu rezulto",
     "Add users or groups" : "Add users or groups",
     "Chat" : "Babili",
-    "Settings" : "Agordoj",
     "Edit" : "Modifi",
+    "Keyboard shortcuts" : "Fulmoklavoj",
+    "Search" : "Serĉi",
     "Share link" : "Kunhavigi ligilon",
     "Password protection" : "Protektita per pasvorto",
     "Enter a password" : "Entajpu pasvorton",
     "Grid view" : "Krada vido",
+    "Default" : "Defaŭlta",
     "The password is wrong. Try again." : "La pasvorto malĝustas. Provu denove.",
-    "Password" : "Pasvorto",
     "Android app" : "Android-aplikaĵo",
     "iOS app" : "iOS-aplikaĵo",
     "Copy" : "Kopii",
