@@ -57,6 +57,7 @@ OC.L10N.register(
     "Enable video" : "Habilitar el video",
     "Screensharing options" : "Opciones de compartir pantalla",
     "Enable screensharing" : "Habilitar compartir pantalla",
+    "Back" : "Atrás",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir tu pantalla. ",
@@ -70,12 +71,20 @@ OC.L10N.register(
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
+    "Settings" : "Configuraciones ",
     "Password protect" : "Proteger con contraseña",
-    "Back" : "Atrás",
     "Close" : "Cerrar",
     "Reply" : "Responder",
+    "Remove" : "Eliminar",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
+    "Enabled" : "Habilitado",
+    "Save" : "Guardar",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Login" : "Iniciar sesión",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "moderator" : "moderador",
     "Demote from moderator" : "Degradar de moderador",
     "Promote to moderator" : "Promover a moderador",
@@ -84,19 +93,20 @@ OC.L10N.register(
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
-    "Settings" : "Configuraciones ",
     "Edit" : "Editar",
+    "Keyboard shortcuts" : "Atajos del teclado",
+    "Search" : "Buscar",
     "Share link" : "Compartir liga",
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingresa una contraseña",
     "Grid view" : "Vista de cuadrícula",
+    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en tu navegador",
     "Please use a different browser like Firefox or Chrome" : "Por favor usa un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "La contraseña está equivoada. Por favor vuelve a intentarlo. ",
-    "Password" : "Contraseña",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "Un servidor externo de señalización puede ser, opcionalmente, utilizado para instalaciones más grandes. Déjalo vacío para usar el sevidor de señalización interno. ",
