@@ -4,6 +4,7 @@ OC.L10N.register(
     "_%n guest_::_%n guests_" : ["%n inivitado","%n inivitados"],
     "Guest" : "Invitado",
     "Open settings" : "Abrir opciones",
+    "Messages" : "Mensajes",
     "Invalid date, date format must be YYYY-MM-DD" : "La fecha es inválida, favor de seguir el formato AAAA-MM-DD",
     "Leave call" : "Dejar la llamada",
     "Limit to groups" : "Limitar a grupos",
@@ -36,6 +37,7 @@ OC.L10N.register(
     "Dismiss" : "Despedir",
     "Mute audio" : "Silenciar audio",
     "Disable video" : "Deshabilitar video",
+    "Back" : "Atrás",
     "Screensharing requires the page to be loaded through HTTPS." : "Compartir pantalla requiere que la página se cargue a través de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la pantalla sólo funciona con Firefox versión 52 o superior. ",
     "Screensharing extension is required to share your screen." : "Se requiere de la extenisón de compartir pantalla para compartir su pantalla. ",
@@ -50,33 +52,44 @@ OC.L10N.register(
     "Loading" : "Cargando",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
+    "Settings" : "Ajustes",
     "Password protect" : "Proteger con contraseña",
-    "Back" : "Atrás",
     "Close" : "Cerrar",
     "Conversation name" : "Nombre de conversación",
+    "Camera" : "Cámara",
     "Reply" : "Responder",
+    "Remove" : "Borrar",
     "Today" : "Hoy",
     "Yesterday" : "Ayer",
     "Send message" : "Enviar mensaje",
+    "Enabled" : "Habilitado",
+    "Save" : "Guardar",
+    "Password" : "Contraseña",
+    "API token" : "Ficha del API",
+    "Login" : "Inicio de sesión",
+    "Nickname" : "Apodo",
+    "Client ID" : "ID del cliente",
     "Searching …" : "Buscando ...",
     "No results" : "Sin resultados",
     "Add users or groups" : "Agregar usuarios o grupos",
     "Participants" : "Participantes",
     "Chat" : "Chat",
-    "Settings" : "Ajustes",
     "Edit" : "Editar",
+    "Keyboard shortcuts" : "Atajos de teclado",
+    "Search" : "Buscar",
     "Rename conversation" : "Renombrar conversación",
     "Share link" : "Compartir link",
     "Password protection" : "Protección con contraseña",
     "Enter a password" : "Ingrese una contraseña",
     "Grid view" : "Vista de cuadrícula",
+    "Start a conversation" : "Iniciar una conversación",
+    "Default" : "Predeterminado",
     "Access to microphone & camera is only possible with HTTPS" : "El acceso al micrófono & cámara sólo es posible mediante HTTPS",
     "Access to microphone & camera was denied" : "El acceso al micrófono & cámara fue denegado",
     "WebRTC is not supported in your browser" : "WebRTC no está soportado en su navegador",
     "Please use a different browser like Firefox or Chrome" : "Favor de usar un navegador diferente como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Se pressentó un error al acceder al micrófono & cámara",
     "The password is wrong. Try again." : "Error en la contraseña. Inténtelo de nuevo.",
-    "Password" : "Contraseña",
     "TURN server" : "Servidor TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "El servidor TURN se usa para concentrar el tráfico de participantes detras de un firewall. ",
     "Android app" : "Aplicación android",
