@@ -23,30 +23,39 @@ OC.L10N.register(
     "Saved" : "Salvestatud",
     "Copy link" : "Kopeeri link",
     "Dismiss" : "Jäta vahele",
+    "Back" : "Tagasi",
     "Screensharing requires the page to be loaded through HTTPS." : "Ekraanijagamiseks tuleb leht laadida üle HTTPS protokolli.",
     "Favorite" : "Lemmik",
     "Remove from favorites" : "Eemalda lemmikutest",
     "Add to favorites" : "Lisa lemmikutesse",
     "Loading" : "Laadimine",
     "Groups" : "Grupid",
+    "Settings" : "Seaded",
     "Password protect" : "Parooliga kaitsmine",
-    "Back" : "Tagasi",
     "Close" : "Sulge",
     "Reply" : "Vasta",
+    "Remove" : "Eemalda",
     "Today" : "Täna",
     "Yesterday" : "Eile",
+    "Enabled" : "Lubatud",
+    "Save" : "Salvesta",
+    "Password" : "Parool",
+    "Login" : "Logi sisse",
+    "Nickname" : "Hüüdnimi",
+    "Client ID" : "Kliendi ID",
     "guest" : "külaline",
     "Searching …" : "Otsin ...",
     "No results" : "Vasteid ei leitud",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Seaded",
     "Edit" : "Redigeeri",
+    "Keyboard shortcuts" : "Klaviatuuri otseteed",
+    "Search" : "Otsi",
     "Share link" : "Jaga link",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
     "Grid view" : "Ruudustikvaade",
+    "Default" : "Vaikeväärtus",
     "The password is wrong. Try again." : "Parool on vale. Proovi uuesti.",
-    "Password" : "Parool",
     "Android app" : "Androidi rakendus",
     "iOS app" : "iOS-i rakendus",
     "Copy" : "Kopeeri",
