@@ -89,6 +89,7 @@ OC.L10N.register(
     "{user} invited you to a private conversation" : "{user} شما را به یک گفتگوی خصوصی دعوت کرد",
     "{user} invited you to a group conversation: {call}" : "{user} شما را به یک گفتگو گروهی دعوت کرد: {call}",
     "Open settings" : "تنظیمات را باز کنید",
+    "Messages" : "پیام ها",
     "United Arab Emirates" : "امارات متحده عربی",
     "Afghanistan" : "افغانستان",
     "Albania" : "آلبانی",
@@ -266,6 +267,7 @@ OC.L10N.register(
     "You can invite others in the participant tab of the sidebar" : "شما می‌توانید دیگران را از زبانه اعضا در نوارکناری دعوت کنید",
     "Share this link to invite others!" : "این پیوند را به اشتراک بگذارید تا دیگران را دعوت کنید!",
     "Dismiss" : "پنهان کن",
+    "Back" : "بازگشت",
     "You" : "شما",
     "Drop your files to upload" : "برای بارگذاری، پرونده‌ها را اینجا رها کنید",
     "Favorite" : "برگزیده",
@@ -276,17 +278,26 @@ OC.L10N.register(
     "Loading" : "در حال بار گزاری",
     "Groups" : "گروه ها",
     "Circles" : "حلقه ها",
+    "Settings" : "تنظیمات",
     "Create a new group conversation" : "ساخت گفتگوی گروهی جدید",
     "Password protect" : "نگهداری کردن رمز عبور",
     "Add participants" : "افزودن عضو",
-    "Back" : "بازگشت",
     "Close" : "بستن",
     "Conversation name" : "نام مکالمه",
     "Allow guests to join via link " : "مجاز بودن عضویت مهمان‌ها با پیوند",
+    "Camera" : "دوربین",
     "Reply" : "پاسخ",
+    "Remove" : "حذف",
     "Today" : "Today",
     "Yesterday" : "دیروز",
     "Send message" : "پیام فرستادن",
+    "Enabled" : "فعال شده",
+    "Save" : "ذخیره",
+    "Password" : "گذرواژه",
+    "API token" : "API token",
+    "Login" : "ورود",
+    "Nickname" : "نام مستعار",
+    "Client ID" : "شناسه مشتری",
     "guest" : "میهمان",
     "Demote from moderator" : "عزل از مدیر",
     "Promote to moderator" : "ترفیع به مدیر",
@@ -296,22 +307,24 @@ OC.L10N.register(
     "Add users or groups" : "کاربران یا گروه ها را اضافه کنید",
     "Add participants to the conversation" : "افزودن عضو به گفتگو",
     "Participants" : "شركت كنندگان",
-    "Projects" : "پروژه ها",
-    "Settings" : "تنظیمات",
     "Edit" : "ویرایش",
+    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
+    "Search" : "جستجو کردن",
     "Rename conversation" : "تغییر نام مکالمه",
     "Share link" : "Share link",
     "Password protection" : "Password protection",
     "Enter a password" : "یک گذرواژه وارد کنید",
     "Fullscreen (f)" : "تمام صفحه (f)",
     "Grid view" : "نمایش گرید",
+    "Say hi to your friends and colleagues!" : "به رفقا و همدرس‌هایتان سلام کنید!",
+    "Start a conversation" : "مکالمه را شروع کنید",
     "Join a conversation or start a new one!" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید!",
     "Join a conversation or start a new one" : "عضو یک گفتگو شوید یا یک گفتگو جدید شروع کنید",
-    "Say hi to your friends and colleagues!" : "به رفقا و همدرس‌هایتان سلام کنید!",
+    "Default" : "پیش‌گزیده",
     "The password is wrong. Try again." : "رمزعبور اشتباه می باشد. دوباره امتحان کنید.",
-    "Password" : "گذرواژه",
     "Android app" : "اپ اندروید",
     "iOS app" : "اپ iOS",
+    "Projects" : "پروژه ها",
     "Copy" : "کپی کردن",
     "Copied!" : "کپی انجام شد!",
     "Not supported!" : "پشتیبانی وجود ندارد!",
