@@ -62,6 +62,7 @@ OC.L10N.register(
     "A group call has started in {call}" : "החלה שיחה קבוצתית תחת {call}",
     "Open settings" : "פתיחת הגדרות",
     "Conversations" : "דיונים",
+    "Messages" : "הודעות",
     "Andorra" : "אנדורה",
     "United Arab Emirates" : "איחוד האמירויות הערביות",
     "Afghanistan" : "אפגניסטן",
@@ -374,6 +375,7 @@ OC.L10N.register(
     "Enable video" : "הפעלת וידאו",
     "Screensharing options" : "אפשרויות שיתוף מסך",
     "Enable screensharing" : "הפעלת שיתוף מסך",
+    "Back" : "חזרה",
     "Screensharing requires the page to be loaded through HTTPS." : "לטובת שיתוף מסך יש לטעון את העמוד דרך HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "שיתוף מסך עובד עם Firefox בגרסה 52 ומעלה.",
     "Screensharing extension is required to share your screen." : "נדרשת הרחבה לשיתוף המסך כדי לשתף את המסך.",
@@ -392,9 +394,9 @@ OC.L10N.register(
     "Loading" : "בטעינה",
     "Groups" : "קבוצות",
     "Circles" : "מעגלים",
+    "Settings" : "הגדרות",
     "Groups and circles" : "קבוצות ומעגלים",
     "Other sources" : "מקורות אחרים",
-    "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Creating your conversation" : "הדיון שלך נוצר",
     "All set" : "הכול מוכן",
     "Copy conversation link" : "העתקת קישור דיון",
@@ -403,7 +405,6 @@ OC.L10N.register(
     "Create a new group conversation" : "יצירת דיון קבוצתי חדש",
     "Password protect" : "הגנה בססמה",
     "Add participants" : "הוספת משתתפים",
-    "Back" : "חזרה",
     "Create conversation" : "יצירת דיון",
     "Close" : "סגירה",
     "Choose a password" : "בחירת ססמה",
@@ -413,7 +414,9 @@ OC.L10N.register(
     "Allow guests to join via link " : "לאפשר לאורחים להצטרף דרך קישור",
     "You are currently waiting in the lobby" : "הנך בהמתנה בלובי",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "בנך בהמתנה בלובי. פגישה זו זומנה ל־{startTime}",
+    "Camera" : "מצלמה",
     "Reply" : "תגובה",
+    "Remove" : "הסרה",
     "[Unknown username]" : "[שם משתמש לא ידוע]",
     "Today" : "היום",
     "Yesterday" : "מחר",
@@ -423,6 +426,14 @@ OC.L10N.register(
     "Share from Files" : "שיתוף מקבצים",
     "Send message" : "שליחת הודעה",
     "File to share" : "קובץ לשיתוף",
+    "Invalid path selected" : "הנתיב שנבחר שגוי",
+    "Enabled" : "מופעל",
+    "Save" : "שמירה",
+    "Password" : "ססמה",
+    "API token" : "אסימון API",
+    "Login" : "התחבר",
+    "Nickname" : "כינוי",
+    "Client ID" : "מזהה לקו",
     "moderator" : "מפקח/ת",
     "guest" : "אורח",
     "Participant settings" : "הגדרות משתתפים",
@@ -441,10 +452,10 @@ OC.L10N.register(
     "Participants" : "משתתפים",
     "An error occurred while fetching the participants" : "אירעה שגיאה במהלך קבלת המשתתפים",
     "Chat" : "צ׳אט",
-    "Projects" : "מיזמים",
-    "Settings" : "הגדרות",
     "Display name: " : "שם תצוגה:",
     "Edit" : "עריכה",
+    "Keyboard shortcuts" : "קיצורי מקלדת",
+    "Search" : "חיפוש",
     "Start call" : "התחלת שיחה",
     "Go to file" : "מעבר לקובץ",
     "Rename conversation" : "שינוי שם הדיון",
@@ -456,16 +467,17 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "יציאה ממסך מלא (f)",
     "Fullscreen (f)" : "מסך מלא (f)",
     "Grid view" : "תצוגת טבלה",
+    "Start a conversation" : "התחלת דיון",
     "Message without mention" : "הודעה ללא אזכור",
     "Mention myself" : "אזכור עצמי",
     "Mention room" : "אזכור חדר",
     "The conversation does not exist" : "הדיון לא קיים",
     "Join a conversation or start a new one!" : "הצטרפות לדיון או ליצור אחד חדש!",
-    "Select a conversation to add to the project" : "בחירת דיון להוספה למיזם",
+    "Link to a conversation" : "קישור לדיון",
     "Select conversation" : "בחירת דיון",
     "Join a conversation or start a new one" : "ניתן להצטרף לדיון או להתחיל באחד חדש.",
-    "Link to a conversation" : "קישור לדיון",
     "Error while sharing file" : "שגיאה בשיתוף הקובץ",
+    "Default" : "בררת מחדל",
     "Access to microphone & camera is only possible with HTTPS" : "גישה למיקרופון ולמצלמה אפשרית רק עם HTTPS",
     "Please move your setup to HTTPS" : "נא להעביר את התצורה שלך ל־HTTPS",
     "Access to microphone & camera was denied" : "הגישה למיקרופון ולמצלמה נדחתה",
@@ -473,12 +485,12 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "נא להשתמש בדפדפן אחר כגון Firefox או Chrome",
     "Error while accessing microphone & camera" : "אירעה שגיאה בעת גישה למיקרופון ולמצלמה",
     "The password is wrong. Try again." : "הססמה שגויה. נא לנסות שוב.",
-    "Password" : "ססמה",
     "TURN server" : "שרת TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "שרת ה־TURN משמש לתיווך התעבורה מהמשתמשים שנמצאים מאחורי חומת אש.",
     "Android app" : "יישומון ל־Android",
     "iOS app" : "יישומון ל־iOS",
     "New conversation …" : "דיון חדש…",
+    "Projects" : "מיזמים",
     "Copy" : "העתקה",
     "Copied!" : "הועתק!",
     "Not supported!" : "אין תמיכה!",
@@ -518,6 +530,7 @@ OC.L10N.register(
     "{participantName}'s screen" : "המסך של {participantName}",
     "Guest's screen" : "המסך של האורח/ת",
     "Limit app usage to groups." : "להגביל את השימוש ביישומון לקבוצות.",
+    "Select a conversation to add to the project" : "בחירת דיון להוספה למיזם",
     "Join conversations at any time, any where, on any device." : "ניתן להצטרף לדיון בכל עת, מכל מקום, בכל מכשיר.",
     "Contacts" : "אנשי קשר",
     "Contacts and groups" : "אנשי קשר וקבוצות",
