@@ -17,22 +17,29 @@ OC.L10N.register(
     "TCP only" : "solo TCP",
     "Copy link" : "Copiar ligamine",
     "Dismiss" : "Dimitter",
+    "Back" : "Retro",
     "You" : "Tu",
     "Favorite" : "Favorite",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "Gruppos",
+    "Settings" : "Configurationes",
     "Password protect" : "Proteger per contrasigno",
-    "Back" : "Retro",
     "Close" : "Clauder",
     "Reply" : "Responder",
     "Today" : "Hodie",
     "Yesterday" : "Heri",
+    "Enabled" : "Activate",
+    "Save" : "Salveguardar",
+    "Password" : "Contrasigno",
+    "Login" : "Login",
+    "Nickname" : "Pseudonymo",
     "guest" : "hospite",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Configurationes",
     "Edit" : "Modificar",
+    "Keyboard shortcuts" : "Combinationes de claves",
+    "Search" : "Cercar",
     "Share link" : "Compartir ligamine",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
@@ -42,7 +49,6 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Per favor, usa un navigator differente tal como Firefox o Chrome",
     "Error while accessing microphone & camera" : "Error durante accesso a microphono e camera",
     "The password is wrong. Try again." : "Le contrasigno es incorrecte. Tenta de novo.",
-    "Password" : "Contrasigno",
     "TURN server" : "servitor TURN",
     "Android app" : "Application Android",
     "iOS app" : "Application iOS",
