@@ -58,6 +58,7 @@ OC.L10N.register(
     "Enable video" : "ვიდეოს ამოქმედება",
     "Screensharing options" : "ეკრანების გაზიარების პარამეტრები",
     "Enable screensharing" : "ეკრანების გაზიარების ნების დართვა",
+    "Back" : "უკან",
     "Screensharing requires the page to be loaded through HTTPS." : "ეკრანების გაზიარება საჭიროებს გვერდის HTTPS პროტოკოლით ჩატვირთვას.",
     "Sharing your screen only works with Firefox version 52 or newer." : "ეკრანის გაზიარება მოქმედია Firefox-ის მხოლოდ 52 ვერსიით ან უფრო ახლით.",
     "Screensharing extension is required to share your screen." : "ეკრანების გასაზიარებლად საჭიროა გაფართოება.",
@@ -71,14 +72,22 @@ OC.L10N.register(
     "Loading" : "იტვირთება",
     "Groups" : "ჯგუფები",
     "Circles" : "წრეები",
+    "Settings" : "პარამეტრები",
     "Password protect" : "პაროლით დაცვა",
-    "Back" : "უკან",
     "Close" : "დახურვა",
     "Conversation name" : "საუბრის სახელწოდება",
     "Reply" : "პასუხი",
+    "Remove" : "წაშლა",
     "Today" : "დღეს",
     "Yesterday" : "გუშინ",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
+    "Enabled" : "მოქმედია",
+    "Save" : "შენახვა",
+    "Password" : "პაროლი",
+    "API token" : "API ტოკენი",
+    "Login" : "ავტორიზაცია",
+    "Nickname" : "ნიკნეიმი",
+    "Client ID" : "კლიენტის ID",
     "moderator" : "მოდერატორი",
     "Demote from moderator" : "ჩამოიქვეითება მოდერატორობისგან",
     "Promote to moderator" : "დაწინაურება მოდერატორობაზე",
@@ -87,19 +96,20 @@ OC.L10N.register(
     "Add users or groups" : "დაამატეთ მომხმარებლები ან ჯგუფები",
     "Participants" : "მონაწილეები",
     "Chat" : "ჩეთი",
-    "Settings" : "პარამეტრები",
     "Edit" : "შეცვლა",
+    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
+    "Search" : "ძიება",
     "Share link" : "ბმულის გაზიარება",
     "Password protection" : "პაროლით თავდაცვა",
     "Enter a password" : "შეიყვანეთ პაროლი",
     "Grid view" : "ბადისებური ხედი",
+    "Default" : "საწყისი",
     "Access to microphone & camera is only possible with HTTPS" : "წვდომა მიკროფონთან და კამერასთან მხარდაჭერილია მხოლოდ HTTPS პროტოკოლით",
     "Access to microphone & camera was denied" : "წვდომა მიკროფონზე და კამერაზე აიკრძალა",
     "WebRTC is not supported in your browser" : "თქვენი ბრაუზერი WebRTC-ს არ უჭერს მხარს",
     "Please use a different browser like Firefox or Chrome" : "გთხოვთ გამოიყენოთ სხვა ბრაუზერი, Firefox-ი ან Chrome-ი",
     "Error while accessing microphone & camera" : "მიკროფონზე და კამერაზე წვდომისას წარმოიშვა შეცდომა",
     "The password is wrong. Try again." : "პაროლი არასწორია. სცადეთ ახლიდან.",
-    "Password" : "პაროლი",
     "TURN server" : "TURN სერვერი",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN სერვერი გამოიყენება ფაირვოლს უკან მყოფი მონაწილეების ტრეფიკის რწმუნებულებების გადასაცემად.",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "დიდი ინსტალაციებისთვის შესაძლებელია გარე სასიგნალო სერვერის გამოყენება. შიდა სიგნალის სერვერის გამოსაყენებლად დატოვეთ ცარიელი.",
