@@ -25,6 +25,7 @@ OC.L10N.register(
     "A group call has started in {call}" : "그룹 통화가 {call}에 시작됨",
     "Open settings" : "설정 열기",
     "Conversations" : "대화",
+    "Messages" : "메시지",
     "Andorra" : "안도라",
     "Afghanistan" : "아프가니스탄",
     "Anguilla" : "앵귈라",
@@ -89,6 +90,7 @@ OC.L10N.register(
     "Enable video" : "비디오 활성화",
     "Screensharing options" : "화면 공유 옵션",
     "Enable screensharing" : "화면 공유 활성화",
+    "Back" : "뒤로",
     "Screensharing requires the page to be loaded through HTTPS." : "화면 공유를 사용하려면 HTTPS로 페이지를 불러 와야 합니다.",
     "Sharing your screen only works with Firefox version 52 or newer." : "화면 공유는 Firefox 버전 52 이상에서만 지원합니다.",
     "Screensharing extension is required to share your screen." : "화면 공유를 위한 확장 기능이 필요합니다.",
@@ -106,15 +108,24 @@ OC.L10N.register(
     "Loading" : "불러오는 중",
     "Groups" : "그룹",
     "Circles" : "서클",
+    "Settings" : "설정",
     "Password protect" : "암호 보호",
-    "Back" : "뒤로",
     "Close" : "닫기",
     "Conversation name" : "대화명",
+    "Camera" : "카메라",
     "Reply" : "답장",
+    "Remove" : "삭제",
     "Today" : "오늘",
     "Yesterday" : "어제",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "메시지 보내기",
+    "Enabled" : "활성화됨",
+    "Save" : "저장",
+    "Password" : "암호",
+    "API token" : "API 토큰",
+    "Login" : "로그인",
+    "Nickname" : "별명",
+    "Client ID" : "클라이언트 ID",
     "moderator" : "중재자",
     "guest" : "손님",
     "Demote from moderator" : "중재자 권한 박탈",
@@ -125,25 +136,28 @@ OC.L10N.register(
     "Add users or groups" : "사용자나 그룹 추가",
     "Participants" : "참가자",
     "Chat" : "대화",
-    "Settings" : "설정",
     "Edit" : "편집",
+    "Keyboard shortcuts" : "키보드 단축키",
+    "Search" : "검색",
     "Rename conversation" : "대화 제목 변경",
     "Share link" : "링크 공유",
     "Password protection" : "암호 보호",
     "Enter a password" : "Enter a password",
     "Grid view" : "바둑판식 보기",
+    "Start a conversation" : "대화 시작",
+    "Default" : "기본값",
     "Access to microphone & camera is only possible with HTTPS" : "마이크와 카메라에는 HTTPS로만 접근할 수 있음",
     "Access to microphone & camera was denied" : "마이크 및 카메라 접근이 거부됨",
     "WebRTC is not supported in your browser" : "웹 브라우저에서 WebRTC를 지원하지 않음",
     "Please use a different browser like Firefox or Chrome" : "Firefox 및 Chrome과 같은 다른 웹 브라우저를 사용하십시오",
     "Error while accessing microphone & camera" : "마이크와 카메라에 접근하는 중 오류 발생",
     "The password is wrong. Try again." : "암호가 잘못되었습니다. 다시 시도하십시오",
-    "Password" : "암호",
     "TURN server" : "TURN 서버",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN 서버는 방화벽 뒤에 있는 참가자의 트래픽을 중계합니다.",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "대규모 사용자가 필요한 경우 외부 신호 서버를 사용할 수 있습니다. 비워 두면 내장 신호 서버를 사용합니다.",
     "Android app" : "Android 앱",
     "iOS app" : "iOS 앱",
+    "Projects" : "프로젝트",
     "Copy" : "복사",
     "Copied!" : "복사 성공!",
     "Not supported!" : "지원하지 않음!",
