@@ -14,26 +14,34 @@ OC.L10N.register(
     "Saved" : "Gespäichert",
     "Copy link" : "Link kopéieren",
     "Dismiss" : "Ofbriechen",
+    "Back" : "Zeréck",
     "Favorite" : "Favorit",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "Gruppen",
+    "Settings" : "Astellungen",
     "Password protect" : "Passwuertgeschützt",
-    "Back" : "Zeréck",
     "Close" : "Zoumaachen",
     "Reply" : "Äntwerten",
+    "Remove" : "Läschen",
     "Today" : "Haut",
     "Yesterday" : "Gëschter",
+    "Enabled" : "Aktivéiert",
+    "Save" : "Späicheren",
+    "Password" : "Passwuert",
+    "Login" : "Login",
+    "Nickname" : "Spëtznumm",
+    "Client ID" : "Client ID",
     "guest" : "Gaascht",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Astellungen",
     "Edit" : "Änneren",
+    "Search" : "Search",
     "Share link" : "Link deelen",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
+    "Default" : "Standard",
     "The password is wrong. Try again." : "Den Passwuert ass incorrect. Probeier ed nach eng keier.",
-    "Password" : "Passwuert",
     "Android app" : "Android-App",
     "iOS app" : "iOS-App",
     "Copied!" : "Kopéiert!",
