@@ -19,26 +19,32 @@ OC.L10N.register(
     "Blocked" : "Хаагдсан",
     "Saved" : "Хадгалах",
     "Dismiss" : "Арилгах",
+    "Back" : "буцах",
     "Favorite" : "Дуртай",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "бүлэгүүд",
     "Circles" : "Тойрог",
+    "Settings" : "Тохиргоо",
     "Password protect" : "Нууц үгээр хамгаалах",
-    "Back" : "буцах",
     "Close" : "Хаах",
     "Reply" : "хариулт",
+    "Remove" : "Устгах",
     "Today" : "өнөөдөр",
     "Yesterday" : "өчигдөр",
+    "Enabled" : "Идэвхижүүлэх",
+    "Save" : "Хадгалах",
+    "Password" : "Нууц үг",
+    "Login" : "Нэвтрэх",
+    "Nickname" : "Товч нэр",
     "No results" : "Үр дүн байхгүй",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Тохиргоо",
     "Edit" : "засварлах",
+    "Search" : "Хайх",
     "Share link" : "Холбоос хуваалцах",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Password" : "Нууц үг",
     "Copy" : "Хуулах",
     "Copied!" : "Хуулсан!",
     "Not supported!" : "Дэмжигдэхгүй",
