@@ -18,6 +18,7 @@ OC.L10N.register(
     "A group call has started in {call}" : "En gruppesamtale har startet i {call}",
     "Open settings" : "Åpne innstillinger",
     "Conversations" : "Samtaler",
+    "Messages" : "Meldinger",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "De forente arabiske emirater",
     "Afghanistan" : "Afganistan",
@@ -86,6 +87,7 @@ OC.L10N.register(
     "User" : "Bruker",
     "Disabled" : "Deaktivert",
     "Users" : "Brukere",
+    "Beta" : "Beta",
     "Name" : "Navn",
     "General settings" : "Generelle innstillinger",
     "Off" : "ett kvarter",
@@ -96,8 +98,8 @@ OC.L10N.register(
     "Pending" : "Venter",
     "Error" : "Feil",
     "Blocked" : "Blokkert",
+    "Active" : "Aktiv",
     "Expired" : "Utløpt",
-    "Signaling server URL" : "Sender signal til servers URL",
     "Validate SSL certificate" : "Bekreft SSL-sertifikat",
     "Saved" : "Lagret",
     "Shared secret" : "Delt hemmelighet",
@@ -126,6 +128,7 @@ OC.L10N.register(
     "Enable video" : "Skru på video",
     "Screensharing options" : "Skjermdelingsvalg",
     "Enable screensharing" : "Skru på skjermdeling",
+    "Back" : "Tilbake",
     "Screensharing requires the page to be loaded through HTTPS." : "Skjermdeling krever at siden er innlastet med HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Deling av skjermen din fungere bare med Firefox versjon 52 eller nyere.",
     "Screensharing extension is required to share your screen." : "Utvidelsen for skjermdeling kreves for å dele skjermen din.",
@@ -141,15 +144,25 @@ OC.L10N.register(
     "Loading" : "Laster",
     "Groups" : "Grupper",
     "Circles" : "Sirkler",
+    "Settings" : "Innstillinger",
     "Password protect" : "Passordbeskyttelse",
-    "Back" : "Tilbake",
     "Close" : "Lukk",
     "Conversation name" : "Samtalenavn",
+    "Camera" : "Kamera",
     "Reply" : "Svar",
+    "Remove" : "Fjern",
     "Today" : "I dag",
     "Yesterday" : "I går",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "Send melding",
+    "Invalid path selected" : "Ugyldig angitt sti",
+    "Enabled" : "Aktivert",
+    "Save" : "Lagre",
+    "Password" : "Passord",
+    "API token" : "API-symbol",
+    "Login" : "Logg inn",
+    "Nickname" : "Kallenavn",
+    "Client ID" : "Klient-ID",
     "moderator" : "moderator",
     "guest" : "gjest",
     "Demote from moderator" : "Fjern moderatorstatus",
@@ -159,9 +172,9 @@ OC.L10N.register(
     "Add users or groups" : "Legg til bruker eller gruppe",
     "Participants" : "Deltakere",
     "Chat" : "Sludre",
-    "Projects" : "Prosjekter",
-    "Settings" : "Innstillinger",
     "Edit" : "Rediger",
+    "Keyboard shortcuts" : "Tastatursnarveier",
+    "Search" : "Søk",
     "Start call" : "Start samtale",
     "Rename conversation" : "Endre navn på samtale",
     "Share link" : "Del lenke",
@@ -170,7 +183,9 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Avslutt fullskjermsvisning (f)",
     "Fullscreen (f)" : "Fullskjermsvisning (f)",
     "Grid view" : "Rutenett-visning",
+    "Start a conversation" : "Start en samtale",
     "Join a conversation or start a new one" : "Ta del i en samtale eller start en ny",
+    "Default" : "Standard",
     "Access to microphone & camera is only possible with HTTPS" : "Tilgang til mikrofon og kamera er kun mulig via HTTPS",
     "Please move your setup to HTTPS" : "Flytt oppsettet ditt til HTTPS",
     "Access to microphone & camera was denied" : "Tilgang til mikrofon og kamera var avvist",
@@ -178,13 +193,13 @@ OC.L10N.register(
     "Please use a different browser like Firefox or Chrome" : "Bruk en annen nettleser, som Firefox eller Chrome",
     "Error while accessing microphone & camera" : "Feil med tilgang til mikrofon og kamera",
     "The password is wrong. Try again." : "Feil passord. Prøv igjen.",
-    "Password" : "Passord",
     "TURN server" : "TURN-server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-serveren fungerer som mellomserver for trafikk fra deltakere bak en brannmur.",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En ekstern signalserver kan alternativt brukes for større installasjoner. La stå tom for å bruke intern signalserver.",
     "Android app" : "Android-app",
     "iOS app" : "iOS-app",
     "New conversation …" : "Ny samtale…",
+    "Projects" : "Prosjekter",
     "Copy" : "Kopier",
     "Copied!" : "Kopiert!",
     "Not supported!" : "Ikke støttet!",
@@ -195,6 +210,7 @@ OC.L10N.register(
     "Cancel" : "Avbryt",
     "Submit" : "Send inn",
     "Guests" : "Gjester",
+    "Webinar" : "Webinar",
     "Change password" : "Endre passord",
     "Set password" : "Velg passord",
     "Rename" : "Gi nytt navn",
@@ -221,6 +237,8 @@ OC.L10N.register(
     "Your screen" : "Din skjerm",
     "{participantName}'s screen" : "{participantName}'s skjerm",
     "Guest's screen" : "Gjestens skjerm",
-    "Contacts" : "Kontakter"
+    "Limit app usage to groups." : "Begrens app-bruk til grupper",
+    "Contacts" : "Kontakter",
+    "Signaling server URL" : "Sender signal til servers URL"
 },
 "nplurals=2; plural=(n != 1);");
