@@ -23,6 +23,7 @@ OC.L10N.register(
     "A group call has started in {call}" : "Uma chamada de grupo começou em {call}",
     "Open settings" : "Abrir definições",
     "Conversations" : "Conversações",
+    "Messages" : "Mensagens",
     "Andorra" : "Andorra",
     "Afghanistan" : "Afeganistão",
     "Armenia" : "Arménia",
@@ -91,6 +92,7 @@ OC.L10N.register(
     "Enable video" : "activar vídeo",
     "Screensharing options" : "Opções de partilha de ecrã",
     "Enable screensharing" : "Activar partilha de ecrã",
+    "Back" : "Anterior",
     "Screensharing requires the page to be loaded through HTTPS." : "A partilha de ecrã requer que a página seja carregada através de HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Partilhar o seu ecrã no Firefox apenas funciona com versão 52 ou mais recente. ",
     "Screensharing extension is required to share your screen." : "Extensão de partilha de ecrã é necessária para partilhar o seu ecrã.",
@@ -106,15 +108,24 @@ OC.L10N.register(
     "Loading" : "A carregar",
     "Groups" : "Grupos",
     "Circles" : "Círculos",
+    "Settings" : "Definições",
     "Password protect" : "Proteger com palavra-passe",
-    "Back" : "Anterior",
     "Close" : "Fechar",
     "Conversation name" : "Nome da conversação",
+    "Camera" : "Câmera",
     "Reply" : "Resposta",
+    "Remove" : "Remover",
     "Today" : "Hoje",
     "Yesterday" : "Ontem",
     "{relativeDate}, {absoluteDate}" : "{relativeDate}, {absoluteDate}",
     "Send message" : "Enviar mensagem",
+    "Enabled" : "Habilidado",
+    "Save" : "Guardar",
+    "Password" : "Palavra-passe",
+    "API token" : "Token de API",
+    "Login" : "Iniciar sessão",
+    "Nickname" : "Alcunha",
+    "Client ID" : "Id. do Cliente",
     "moderator" : "moderador",
     "guest" : "convidado",
     "Demote from moderator" : "Relegar de moderador",
@@ -124,20 +135,22 @@ OC.L10N.register(
     "Add users or groups" : "Add users or groups",
     "Participants" : "Participantes",
     "Chat" : "Conversa",
-    "Settings" : "Definições",
     "Edit" : "Editar",
+    "Keyboard shortcuts" : "Atalhos de teclado",
+    "Search" : "Pesquisa sobre",
     "Rename conversation" : "Renomear conversação",
     "Share link" : "Partilhar hiperligação",
     "Password protection" : "Protegido por palavra-passe",
     "Enter a password" : "Insira uma palavra-passe",
     "Grid view" : "Vista em grelha",
+    "Start a conversation" : "Iniciar uma conversação",
+    "Default" : "Predefinida",
     "Access to microphone & camera is only possible with HTTPS" : "Só é possível aceder ao microfone & câmera com HTTPS",
     "Access to microphone & camera was denied" : "Acesso recusado ao microfone & câmera",
     "WebRTC is not supported in your browser" : "WebRTC não é suportado pelo seu browser",
     "Please use a different browser like Firefox or Chrome" : "Por favor use um browser diferente como Firefox ou Chrome",
     "Error while accessing microphone & camera" : "Erro a aceder ao microfone & câmera",
     "The password is wrong. Try again." : "A palavra-passe está errada. Por favor, tente de novo.",
-    "Password" : "Palavra-passe",
     "Android app" : "Aplicação Android",
     "iOS app" : "Aplicação iOS",
     "Copy" : "Copiar",
