@@ -257,30 +257,40 @@ OC.L10N.register(
     "Saved" : "Salvat",
     "Copy link" : "Copiză link",
     "Dismiss" : "Elimină",
+    "Back" : "Înapoi",
     "Favorite" : "Favorite",
     "Remove from favorites" : "Șterge din favorite",
     "Add to favorites" : "Adăugați la favorite",
     "Loading" : "Loading",
     "Groups" : "Grupuri",
     "Circles" : "Cercuri",
+    "Settings" : "Setări",
     "Password protect" : "Protejare cu parolă",
-    "Back" : "Înapoi",
     "Close" : "Închide",
+    "Camera" : "Cameră",
     "Reply" : "Răspunde",
+    "Remove" : "Șterge",
     "Today" : "Azi",
     "Yesterday" : "Ieri",
+    "Enabled" : "Activat",
+    "Save" : "Salvează",
+    "Password" : "Parolă",
+    "Login" : "Autentificare",
+    "Nickname" : "Pseudonim",
+    "Client ID" : "ID client",
     "guest" : "invitat",
     "No results" : "Niciun rezultat",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Setări",
     "Edit" : "Editează",
+    "Keyboard shortcuts" : "Scurtături din tastatură",
+    "Search" : "Caută",
     "Share link" : "Partajează link-ul",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
     "Grid view" : "Afișare în grilă",
+    "Default" : "Implicit",
     "Access to microphone & camera was denied" : "Accesul la microfon și cameră a fost refuzat",
     "The password is wrong. Try again." : "Parola este incorectă. Încercaţi din nou.",
-    "Password" : "Parolă",
     "Android app" : "Aplicație Android",
     "iOS app" : "Aplicație iOS",
     "Copy" : "Copiază",
