@@ -174,6 +174,7 @@ OC.L10N.register(
     "Dismiss" : "Hiq",
     "Mute audio" : "Mute audio",
     "Disable video" : "Çaktivizo video",
+    "Back" : "Prapa",
     "Screensharing requires the page to be loaded through HTTPS." : "Ndarja e ekranit kërkon faqen të ngarkohet përmes HTTPS.",
     "Sharing your screen only works with Firefox version 52 or newer." : "Ndarja e ekranit punon vetëm me Firefox, versionin 52 ose më të ri.",
     "Screensharing extension is required to share your screen." : "Zgjerim i ndarja së Ekranit është i nevojshëm për të ndarë ekranin tuaj.",
@@ -188,31 +189,42 @@ OC.L10N.register(
     "Loading" : "Duke ngarkuar",
     "Groups" : "Grupet",
     "Circles" : "Rrethet",
+    "Settings" : "Rregullimet",
     "Password protect" : "Mbroje me fjalëkalim",
-    "Back" : "Prapa",
     "Close" : "Mbylleni",
     "Conversation name" : "Emri i bisedës",
+    "Camera" : "Kamera",
     "Reply" : "Përgjigju",
+    "Remove" : "Hiq",
     "Today" : "Sot",
     "Yesterday" : "Dje",
     "Send message" : "Dërgo mesazh",
+    "Enabled" : "I aktivizuar",
+    "Save" : "Ruaj",
+    "Password" : "Fjalëkalim",
+    "API token" : "Çelës identifikues i API-t ",
+    "Login" : "Hyrje",
+    "Nickname" : "Nofkë",
+    "Client ID" : "ID klienti",
     "guest" : "vizitor",
     "No results" : "Asnjë rezultat",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "Rregullimet",
     "Edit" : "Përpuno",
+    "Keyboard shortcuts" : "Shkurtoret e tastierës",
+    "Search" : "Kërko",
     "Rename conversation" : "Riemërtojeni bisedën",
     "Share link" : "Shpërndaj ndërlidhjen",
     "Password protection" : "Password protection",
     "Enter a password" : "Fusni një fjalëkalim",
     "Grid view" : "Pamje galeri",
+    "Start a conversation" : "Filloni një bisedë",
+    "Default" : "E paracaktuar",
     "Access to microphone & camera is only possible with HTTPS" : "Aksesi në mikrofon & kamera është i mundur vetëm me HTTPS",
     "Access to microphone & camera was denied" : "Aksesi tek mikrofoni & kamera u mohua",
     "WebRTC is not supported in your browser" : "WebRTC nuk mbështetet nga shfletuesi juaj.",
     "Please use a different browser like Firefox or Chrome" : "Ju lutem zgjidhni një shfletues tjetër si Firefox apo Chrome",
     "Error while accessing microphone & camera" : "gabim ",
     "The password is wrong. Try again." : "Fjalëkalim i gabuar. Provojeni sërish.",
-    "Password" : "Fjalëkalim",
     "TURN server" : "Serveri TURN",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "Serveri TURN përdoret për të përcjellë trafikun nga pjesëmarrësit pas një firewalli.",
     "Android app" : "Aplikacion Android",
