@@ -3,6 +3,7 @@ OC.L10N.register(
     {
     "Guest" : "Gost",
     "Open settings" : "Otvori postavke",
+    "Messages" : "Poruke",
     "None" : "Ništa",
     "User" : "User",
     "Name" : "naziv",
@@ -11,6 +12,7 @@ OC.L10N.register(
     "Error" : "Greška",
     "Copy link" : "Kopiraj vezu",
     "Dismiss" : "Odbaci",
+    "Back" : "Nazad",
     "Favorite" : "Omiljeni",
     "Leave conversation" : "Napusti razgovor",
     "Delete conversation" : "Obriši razgovor",
@@ -18,14 +20,19 @@ OC.L10N.register(
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "Grupe",
+    "Settings" : "Поставке",
     "Password protect" : "Zaštita lozinkom",
-    "Back" : "Nazad",
     "Close" : "Zatvori",
     "Conversation name" : "Naziv razgovora",
+    "Camera" : "Kamera",
     "Reply" : "Odgovori",
+    "Remove" : "Ukloni",
     "Today" : "Today",
     "Yesterday" : "juče",
     "Send message" : "Pošalji poruku",
+    "Save" : "Sačuvaj",
+    "Password" : "Password",
+    "Login" : "Korisničko ime",
     "guest" : "gost",
     "Demote from moderator" : "Skini ulogu moderatora",
     "Promote to moderator" : "Unapredi u moderatora",
@@ -33,14 +40,15 @@ OC.L10N.register(
     "No results" : "Nema rezultata",
     "Add users or groups" : "Add users or groups",
     "Participants" : "Učesnici",
-    "Settings" : "Поставке",
     "Edit" : "Uredi",
+    "Search" : "Traži",
     "Rename conversation" : "Preimenuj razgovor",
     "Share link" : "Veza deljenja",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
     "Grid view" : "Prikaz mreže",
-    "Password" : "Password",
+    "Start a conversation" : "Započni razgovor",
+    "Default" : "Podrazumevano",
     "Copy" : "Kopiraj",
     "Copied!" : "Копирано!",
     "Not supported!" : "Није подржано!",
