@@ -128,6 +128,7 @@ OC.L10N.register(
     "Someone tried to request the password to access {file}" : "Någon försökte begära lösenordet för att komma åt {file}",
     "Open settings" : "Öppna inställningar",
     "Conversations" : "Konversationer",
+    "Messages" : "Meddelanden",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Förenade arabemiraten",
     "Afghanistan" : "Afghanistan",
@@ -425,7 +426,6 @@ OC.L10N.register(
     "Blocked" : "Blockerar",
     "Active" : "Aktiv",
     "Expired" : "Utgånget",
-    "Signaling server URL" : "Signalerar serverwebbadress",
     "Validate SSL certificate" : "Validera SSL-certifikat",
     "Delete this server" : "Ta bort denna server",
     "Status: Checking connection" : "Status: Kontrollerar anslutning",
@@ -434,7 +434,6 @@ OC.L10N.register(
     "Error: Server did not respond with proper JSON" : "Error: Servern svarade inte med korrekt JSON",
     "Error: Server responded with: {error}" : "Error: Servern svarade med: {error}",
     "Error: Unknown error occurred" : "Error: Okänt fel inträffade",
-    "Signaling servers" : "Signalservrar",
     "Saved" : "Sparad",
     "Add a new server" : "Lägg till ny server",
     "An external signaling server should optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver bör eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
@@ -478,6 +477,7 @@ OC.L10N.register(
     "Enable video. Your connection will be briefly interrupted when enabling the video for the first time" : "Aktivera video. Din anslutning får ett kort avbrott när du aktiverar video första gången",
     "Screensharing options" : "Skärmdelningsalternativ",
     "Enable screensharing" : "Tillåt skärmdelning",
+    "Back" : "Tillbaka",
     "Screen sharing is not supported by your browser." : "Skärmdelning stöds inte av din webbläsare.",
     "Screen sharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver att sidan läses in via HTTPS.",
     "Screensharing requires the page to be loaded through HTTPS." : "Skärmdelning kräver HTTPS",
@@ -511,15 +511,12 @@ OC.L10N.register(
     "No search results" : "Inga sökresultat",
     "Groups" : "Grupper",
     "Circles" : "Cirklar",
-    "Default location for attachments" : "Standardplats för bilagor",
+    "Settings" : "Inställnigar",
     "Users, groups and circles" : "Användare, grupper och cirklar",
     "Users and groups" : "Användare och grupper",
     "Users and circles" : "Användare och cirklar",
     "Groups and circles" : "Grupper och cirklar",
     "Other sources" : "Andra källor",
-    "Select default location for attachments" : "Välj standardplats för bilagor",
-    "Invalid path selected" : "Ogiltig sökväg vald",
-    "Error while setting attachment folder" : "Fel vid inställning av mapp för bilagor",
     "Creating your conversation" : "Skapar din konversation",
     "All set" : "Allt klart",
     "Copy conversation link" : "Kopiera konversationslänk",
@@ -528,7 +525,6 @@ OC.L10N.register(
     "Create a new group conversation" : "Skapa en ny gruppkonversation",
     "Password protect" : "Lösenordsskydda",
     "Add participants" : "Lägg till deltagare",
-    "Back" : "Tillbaka",
     "Create conversation" : "Skapa konversation",
     "Close" : "Stäng",
     "Choose a password" : "Välj ett lösenord",
@@ -539,7 +535,9 @@ OC.L10N.register(
     "Search conversations or users" : "Sök konversationer eller användare",
     "You are currently waiting in the lobby" : "Du väntar för närvarande i lobbyn",
     "You are currently waiting in the lobby. This meeting is scheduled for {startTime}" : "Du väntar för närvarande i lobbyn. Detta möte är planerat till {startTime}",
+    "Camera" : "Kamera",
     "Reply" : "Svara",
+    "Remove" : "Radera",
     "[Unknown username]" : "[Okänt användarnamn]",
     "Today" : "Idag",
     "Yesterday" : "Igår",
@@ -550,6 +548,14 @@ OC.L10N.register(
     "Share from Files" : "Dela från Filer",
     "Send message" : "Skicka meddelande",
     "File to share" : "Fil att dela",
+    "Invalid path selected" : "Ogiltig sökväg vald",
+    "Enabled" : "Aktiverad",
+    "Save" : "Spara",
+    "Password" : "Lösenord",
+    "API token" : "API-token",
+    "Login" : "Logga in",
+    "Nickname" : "Smeknamn",
+    "Client ID" : "Klient-ID",
     "moderator" : "moderator",
     "guest" : "gäst",
     "Participant settings" : "Deltagarinställningar",
@@ -572,10 +578,11 @@ OC.L10N.register(
     "Participants" : "Deltagare",
     "An error occurred while fetching the participants" : "Ett fel uppstod när deltagarna hämtades",
     "Chat" : "Chat",
-    "Projects" : "Projekt",
-    "Settings" : "Inställnigar",
     "Display name: " : "Visningsnamn:",
     "Edit" : "Ändra",
+    "Keyboard shortcuts" : "Tangentbordsgenvägar",
+    "Search" : "Sök",
+    "Error while setting attachment folder" : "Fel vid inställning av mapp för bilagor",
     "Start call" : "Starta samtal",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call." : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal.",
     "You will be able to join the call only after a moderator starts it." : "Du kommer att kunna gå med i samtalet först när en moderator startar det.",
@@ -590,16 +597,16 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Avsluta fullskärmsläge (f)",
     "Fullscreen (f)" : "Fullskärm (f)",
     "Grid view" : "Rutnätsvy",
+    "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
+    "Start a conversation" : "Starta en konversation",
     "Message without mention" : "Meddelande utan omnämnande",
     "Mention myself" : "Nämn mig själv",
     "Mention room" : "Nämn rum",
     "The conversation does not exist" : "Konversationen finns inte",
     "Join a conversation or start a new one!" : "Anslut till en konversation eller starta en ny!",
-    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
+    "Link to a conversation" : "Länka till en konversation",
     "Select conversation" : "Välj konversation",
     "Join a conversation or start a new one" : "Anslut till en konversation eller starta en ny",
-    "Say hi to your friends and colleagues!" : "Säg hej till dina vänner och kollegor!",
-    "Link to a conversation" : "Länka till en konversation",
     "The browser you're using is not fully supported by Nextcloud Talk. Please use the latest version of Mozilla Firefox, Microsoft Edge, Google Chrome or Apple Safari." : "Webbläsaren du använder stöds inte av Nextcloud Talk. Använd den senaste versionen av Mozilla Firefox, Microsoft Edge, Google Chrome eller Apple Safari.",
     "Nextcloud Talk was updated, please reload the page" : "Nextcloud Talk uppdaterades, ladda om sidan igen",
     "Nextcloud is in maintenance mode, please reload the page" : "Nextcloud är i underhållsläge, ladda om sidan igen",
@@ -608,6 +615,7 @@ OC.L10N.register(
     "Sending signaling message has failed." : "Misslyckades skicka signalmeddelande.",
     "Establishing signaling connection is taking longer than expected …" : "Det tar längre tid än förväntat att upprätta signalanslutning ...",
     "Failed to establish signaling connection. Retrying …" : "Det gick inte att upprätta signalanslutning. Försöker igen ...",
+    "Default" : "Standard",
     "You seem to be talking while muted, please unmute yourself for others to hear you" : "Du verkar prata med avstängd mikrofon, sätt på mikrofonen för att andra ska höra dig",
     "Could not establish a connection with at least one participant. A TURN server might be needed for your scenario. Please ask your administrator to set one up following {linkstart}this documentation{linkend}." : "Det gick inte att upprätta en anslutning med minst en deltagare. En TURN-server kan behövas för ditt scenario. Be din administratör att sätta upp en efter {linkstart}den här dokumentationen{linkend}.",
     "This is taking longer than expected. Are the media permissions already granted (or rejected)? If yes please restart your browser, as audio and video are failing" : "Det tar längre tid än väntat. Har mediarättigheter redan beviljats (eller avvisats)? Om ja, starta om din webbläsare, eftersom ljud och video misslyckas",
@@ -619,10 +627,10 @@ OC.L10N.register(
     "Error while accessing microphone & camera" : "Fel vid åtkomst till mikrofon och kamera",
     "This conversation is password-protected" : "Denna konversation är lösenordsskyddad",
     "The password is wrong. Try again." : "Lösenordet är fel. Försök igen.",
-    "Password" : "Lösenord",
     "Specify commands the users can use in chats" : "Ange kommandon som användare kan använda i chattar",
     "TURN server" : "TURN-server",
     "The TURN server is used to proxy the traffic from participants behind a firewall." : "TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
+    "Signaling servers" : "Signalservrar",
     "An external signaling server can optionally be used for larger installations. Leave empty to use the internal signaling server." : "En extern signalserver kan eventuellt användas för större installationer. Lämna tomt för att använda den interna signalservern.",
     "%s Talk on your mobile devices" : "%s Talk på dina mobila enheter",
     "Join conversations at any time, anywhere, on any device." : "Gå med i konversationer när som helst, var som helst, på alla enheter.",
@@ -631,6 +639,7 @@ OC.L10N.register(
     "Enter name for a new conversation" : "Ange namn för en ny konversation",
     "{name} (public)" : "{name} (publik)",
     "New conversation …" : "Ny konversation",
+    "Projects" : "Projekt",
     "Calls with more than 4 participants without an external signaling server can experience connectivity issues and cause high load on participating devices." : "Samtal med fler än 4 deltagare utan att en extern signalserver kan uppleva anslutningsproblem och orsaka hög belastning på deltagande enheter.",
     "Copy" : "Kopiera",
     "Copied!" : "Kopierat!",
@@ -693,6 +702,7 @@ OC.L10N.register(
     "Commands are a new beta feature in Nextcloud Talk. They allow you to run scripts on your Nextcloud server. You can define them with our command line interface. An example of a calculator script can be found in our <a {attributes}>documentation ↗</a>." : "Kommandon är en ny beta-funktion i Nextcloud Talk. Det låter dig köra skript på din Nextcloud-server. Du kan definiera dem med vårt kommandoradsgränssnitt. Ett exempel på ett kalkylatorskript finns i vår <a {attributes}>dokumentation ↗</a>.",
     "Start calls" : "Starta samtal",
     "Who can start a call?" : "Vem kan starta ett samtal?",
+    "Select a conversation to add to the project" : "Välj en konversation som ska läggas till i projektet",
     "A TURN server is used to proxy the traffic from participants behind a firewall." : "En TURN-servern används för att tunnla trafiken för användare som sitter bakom en brandvägg.",
     "Join conversations at any time, any where, on any device." : "Anslut dig till konversationer när som helst, var som helst och på valfri enhet.",
     "Contacts" : "Kontakter",
@@ -708,6 +718,9 @@ OC.L10N.register(
     "Add contacts, groups or circles" : "Lägg till kontakter, grupper och cirklar",
     "Add contacts or groups" : "Lägg till kontakter eller grupper",
     "Add contacts or circles" : "Lägg till kontakter eller cirklar",
+    "Signaling server URL" : "Signalerar serverwebbadress",
+    "Default location for attachments" : "Standardplats för bilagor",
+    "Select default location for attachments" : "Välj standardplats för bilagor",
     "Nextcloud Talk was updated, you need to reload the page before you can start or join a call" : "Nextcloud Talk uppdaterades, du måste ladda om sidan innan du kan starta eller gå med i ett samtal"
 },
 "nplurals=2; plural=(n != 1);");
