@@ -15,27 +15,36 @@ OC.L10N.register(
     "Saved" : "บันทึกแล้ว",
     "Copy link" : "คัดลอกลิงค์",
     "Dismiss" : "ยกเลิก",
+    "Back" : "ย้อนกลับ",
     "Favorite" : "รายการโปรด",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "กลุ่ม",
+    "Settings" : "ตั้งค่า",
     "Password protect" : "ป้องกันด้วยรหัสผ่าน",
-    "Back" : "ย้อนกลับ",
     "Close" : "ปิด",
     "Reply" : "ตอบกลับ",
+    "Remove" : "ลบออก",
     "Today" : "วันนี้",
     "Yesterday" : "เมื่อวานนี้",
+    "Enabled" : "เปิดการใช้งาน",
+    "Save" : "บันทึก",
+    "Password" : "รหัสผ่าน",
+    "Login" : "Login",
+    "Nickname" : "ชื่อเล่น",
+    "Client ID" : "Client ID",
     "guest" : "ผู้เยี่ยมชม",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "ตั้งค่า",
     "Edit" : "แก้ไข",
+    "Keyboard shortcuts" : "ปุ่มลัด",
+    "Search" : "Search",
     "Share link" : "แชร์ลิงค์",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
     "Grid view" : "มุมมองแบบตาราง Grid",
+    "Default" : "ค่าเริ่มต้น",
     "The password is wrong. Try again." : "รหัสผ่านที่ไม่ถูกต้อง กรุณาลองอีกครั้ง",
-    "Password" : "รหัสผ่าน",
     "Android app" : "แอพฯ แอนดรอยด์",
     "iOS app" : "แอพฯ IOS",
     "Copy" : "คัดลอก",
