@@ -83,6 +83,7 @@ OC.L10N.register(
     "Enable video" : "Увімкнути відео",
     "Screensharing options" : "Параметри демонстрації екрану",
     "Enable screensharing" : "Увімкнути демонстрацію екрану",
+    "Back" : "Назад",
     "Screen sharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
     "Screensharing requires the page to be loaded through HTTPS." : "Демонстрація екрану вимагає доступу до сторінки через безпечний протокол https.",
     "You" : "Ви",
@@ -101,13 +102,10 @@ OC.L10N.register(
     "Loading" : "Завантаження",
     "No search results" : "Відсутні результати",
     "Groups" : "Групи",
-    "Default location for attachments" : "Типове розташування для вкладень",
-    "Select default location for attachments" : "Виберіть типове розташування для вкладень",
-    "Invalid path selected" : "Вибрано неправильний шлях",
+    "Settings" : "Налаштування",
     "Create a new group conversation" : "Створити нову групову розмову",
     "Password protect" : "Захистити паролем",
     "Add participants" : "Додати учасників",
-    "Back" : "Назад",
     "Create conversation" : "Створити розмову",
     "Close" : "Закрити",
     "Search participants" : "Пошук учасників",
@@ -115,7 +113,9 @@ OC.L10N.register(
     "Allow guests to join via link " : "Дозволити гостям приєднуватися через посилання",
     "Search conversations or users" : "Пошук розмов та учасників",
     "You are currently waiting in the lobby" : "Чекаємо на схвалення доступу",
+    "Camera" : "Камера",
     "Reply" : "Відповісти",
+    "Remove" : "Вилучити",
     "Today" : "Сьогодні",
     "Yesterday" : "Вчора",
     "Write message, @ to mention someone …" : "Написати повідомлення, @ім'я для згадки про користувача…",
@@ -123,6 +123,13 @@ OC.L10N.register(
     "Upload new files" : "Додати файл",
     "Share from Files" : "Відкрити Файли",
     "File to share" : "Виберіть файл для надання доступу",
+    "Invalid path selected" : "Вибрано неправильний шлях",
+    "Enabled" : "Увімкнено",
+    "Save" : "Зберегти",
+    "Password" : "Пароль",
+    "Login" : "Login",
+    "Nickname" : "Прізвисько",
+    "Client ID" : "Ідентифікатор клієнта",
     "guest" : "гість",
     "Add users" : "Додати користувачів",
     "Add groups" : "Додати групи",
@@ -135,9 +142,9 @@ OC.L10N.register(
     "Add participants to the conversation" : "Додати учасників до розмови",
     "Participants" : "Учасники",
     "Chat" : "Чат",
-    "Projects" : "Проєкти",
-    "Settings" : "Налаштування",
     "Edit" : "Редагувати",
+    "Keyboard shortcuts" : "Гарячі клавіші",
+    "Search" : "Пошук",
     "Start call" : "Почати виклик",
     "Toggle fullscreen" : "Перемкнути на весь екран",
     "Rename conversation" : "Перейменувати розмову",
@@ -148,18 +155,18 @@ OC.L10N.register(
     "Exit fullscreen (f)" : "Вийти з повного екрану (f)",
     "Fullscreen (f)" : "На весь екран (f)",
     "Grid view" : "Упорядкування у формі сітки",
-    "Join a conversation or start a new one!" : "Приєднайтеся до розмови або почніть нову!",
-    "Select a conversation to add to the project" : "Виберіть розмову, яку потрібно додати до проєкту",
-    "Join a conversation or start a new one" : "Приєднайтеся до розмови або почніть нову",
     "Say hi to your friends and colleagues!" : "Привітайтеся з вашими друзями та колегами!",
+    "Join a conversation or start a new one!" : "Приєднайтеся до розмови або почніть нову!",
+    "Join a conversation or start a new one" : "Приєднайтеся до розмови або почніть нову",
     "Error while sharing file" : "Помилка під час надання спільного доступу до файлу",
+    "Default" : "За замовчуванням",
     "Access to microphone & camera is only possible with HTTPS" : "Доступ до мікрофона та камери можливий лише через безпечний протокол https.",
     "Please move your setup to HTTPS" : "Будь ласка, налаштуйте безпечний доступ до сервера через https.",
     "The password is wrong. Try again." : "Пароль неправильний. Спробуйте ще раз.",
-    "Password" : "Пароль",
     "Android app" : "Застосунок для Android",
     "iOS app" : "Застосунок для iOS",
     "Enter name for a new conversation" : "Зазначте ім'я для нової розмови",
+    "Projects" : "Проєкти",
     "Copy" : "Копіювати",
     "Copied!" : "Скопійовано!",
     "Not supported!" : "Не підтримується!",
@@ -181,9 +188,12 @@ OC.L10N.register(
     "Guest's screen" : "Екран гостя",
     "Start calls" : "Почати виклики",
     "Who can start a call?" : "Хто може здійснювати виклики?",
+    "Select a conversation to add to the project" : "Виберіть розмову, яку потрібно додати до проєкту",
     "Contacts" : "Контакти",
     "Select participants" : "Виберіть учасників",
     "Search conversations or contacts" : "Пошук розмов та контактів",
-    "Search for more contacts" : "Шукати більше контактів"
+    "Search for more contacts" : "Шукати більше контактів",
+    "Default location for attachments" : "Типове розташування для вкладень",
+    "Select default location for attachments" : "Виберіть типове розташування для вкладень"
 },
 "nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
