@@ -12,23 +12,30 @@ OC.L10N.register(
     "Error" : "錯誤",
     "Saved" : "已儲存",
     "Copy link" : "複製連結",
+    "Back" : "返回",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
     "Loading" : "Loading",
     "Groups" : "群組",
+    "Settings" : "設定",
     "Password protect" : "密碼保護",
-    "Back" : "返回",
     "Close" : "關閉",
     "Reply" : "回覆",
+    "Remove" : "刪除",
     "Today" : "今日",
     "Yesterday" : "明日",
+    "Enabled" : "啟用",
+    "Save" : "儲存",
+    "Password" : "密碼",
+    "Login" : "Login",
+    "Nickname" : "暱稱",
     "Add users or groups" : "Add users or groups",
-    "Settings" : "設定",
     "Edit" : "編輯",
+    "Search" : "Search",
     "Share link" : "分享連結",
     "Password protection" : "Password protection",
     "Enter a password" : "Enter a password",
-    "Password" : "密碼",
+    "Default" : "預設",
     "Android app" : "Android 應用程式",
     "iOS app" : "iOS 應用程式",
     "Copied!" : "已複製!",
