@@ -27,6 +27,7 @@ declare(strict_types=1);
 
 namespace OCA\Talk\Controller;
 
+use InvalidArgumentException;
 use OCA\Circles\Api\v1\Circles;
 use OCA\Circles\Model\Member;
 use OCA\Talk\Chat\ChatManager;
@@ -41,6 +42,7 @@ use OCA\Talk\GuestManager;
 use OCA\Talk\Manager;
 use OCA\Talk\Participant;
 use OCA\Talk\Room;
+use OCA\Talk\Service\RoomService;
 use OCA\Talk\TalkSession;
 use OCA\Talk\Webinary;
 use OCP\App\IAppManager;
@@ -56,6 +58,9 @@ use OCP\IUserManager;
 use OCP\IGroup;
 use OCP\IGroupManager;
 use OCP\IConfig;
+use OCP\User\Events\UserLiveStatusEvent;
+use OCP\UserStatus\IManager as IUserStatusManager;
+use OCP\UserStatus\IUserStatus;
 
 class RoomController extends AEnvironmentAwareController {
 	public const EVENT_BEFORE_ROOMS_GET = self::class . '::preGetRooms';
@@ -72,8 +77,12 @@ class RoomController extends AEnvironmentAwareController {
 	protected $groupManager;
 	/** @var Manager */
 	protected $manager;
+	/** @var RoomService */
+	protected $roomService;
 	/** @var GuestManager */
 	protected $guestManager;
+	/** @var IUserStatusManager */
+	protected $statusManager;
 	/** @var ChatManager */
 	protected $chatManager;
 	/** @var IEventDispatcher */
@@ -97,7 +106,9 @@ class RoomController extends AEnvironmentAwareController {
 								IUserManager $userManager,
 								IGroupManager $groupManager,
 								Manager $manager,
+								RoomService $roomService,
 								GuestManager $guestManager,
+								IUserStatusManager $statusManager,
 								ChatManager $chatManager,
 								IEventDispatcher $dispatcher,
 								MessageParser $messageParser,
@@ -112,7 +123,9 @@ class RoomController extends AEnvironmentAwareController {
 		$this->userManager = $userManager;
 		$this->groupManager = $groupManager;
 		$this->manager = $manager;
+		$this->roomService = $roomService;
 		$this->guestManager = $guestManager;
+		$this->statusManager = $statusManager;
 		$this->chatManager = $chatManager;
 		$this->dispatcher = $dispatcher;
 		$this->messageParser = $messageParser;
@@ -143,12 +156,30 @@ class RoomController extends AEnvironmentAwareController {
 	 *
 	 * @NoAdminRequired
 	 *
+	 * @param int $noStatusUpdate When the user status should not be automatically set to online set to 1 (default 0)
 	 * @return DataResponse
 	 */
-	public function getRooms(): DataResponse {
+	public function getRooms(int $noStatusUpdate = 0): DataResponse {
 		$event = new UserEvent($this->userId);
 		$this->dispatcher->dispatch(self::EVENT_BEFORE_ROOMS_GET, $event);
 
+		if ($noStatusUpdate === 0) {
+			$isMobileApp = $this->request->isUserAgent([
+				IRequest::USER_AGENT_TALK_ANDROID,
+				IRequest::USER_AGENT_TALK_IOS,
+			]);
+
+			if ($isMobileApp) {
+				// Bump the user status again
+				$event = new UserLiveStatusEvent(
+					$this->userManager->get($this->userId),
+					IUserStatus::ONLINE,
+					$this->timeFactory->getTime()
+				);
+				$this->dispatcher->dispatchTyped($event);
+			}
+		}
+
 		$rooms = $this->manager->getRoomsForParticipant($this->userId, true);
 
 		$return = [];
@@ -487,7 +518,13 @@ class RoomController extends AEnvironmentAwareController {
 				$lastReadMessage = $this->chatManager->getLastReadMessageFromLegacy($room, $currentUser);
 				$currentParticipant->setLastReadMessage($lastReadMessage);
 			}
-			$roomData['unreadMessages'] = $this->chatManager->getUnreadCount($room, $lastReadMessage);
+			if ($room->getLastMessage() && $lastReadMessage === (int) $room->getLastMessage()->getId()) {
+				// When the last message is the last read message, there are no unread messages,
+				// so we can save the query.
+				$roomData['unreadMessages'] = 0;
+			} else {
+				$roomData['unreadMessages'] = $this->chatManager->getUnreadCount($room, $lastReadMessage);
+			}
 
 			$lastMention = $currentParticipant->getLastMentionMessage();
 			$roomData['unreadMention'] = $lastMention !== 0 && $lastReadMessage < $lastMention;
@@ -495,17 +532,15 @@ class RoomController extends AEnvironmentAwareController {
 
 			$roomData['canDeleteConversation'] = $room->getType() !== Room::ONE_TO_ONE_CALL
 				&& $currentParticipant->hasModeratorPermissions(false);
-			$roomData['canLeaveConversation'] = !$roomData['canDeleteConversation']
-				|| ($room->getType() !== Room::ONE_TO_ONE_CALL && $room->getNumberOfParticipants() > 1);
+			$roomData['canLeaveConversation'] = true;
 		}
 
 		// FIXME This should not be done, but currently all the clients use it to get the avatar of the user …
 		if ($room->getType() === Room::ONE_TO_ONE_CALL) {
-			$participants = $room->getParticipants();
+			$participants = json_decode($room->getName(), true);
 			foreach ($participants as $participant) {
-				$user = $this->userManager->get($participant->getUser());
-				if ($user instanceof IUser && $user->getUID() !== $currentParticipant->getUser()) {
-					$roomData['name'] = $user->getUID();
+				if ($participant !== $currentParticipant->getUser()) {
+					$roomData['name'] = $participant;
 				}
 			}
 		}
@@ -581,40 +616,43 @@ class RoomController extends AEnvironmentAwareController {
 	 *
 	 * @NoAdminRequired
 	 *
-	 * @param string $targetUserName
+	 * @param string $targetUserId
 	 * @return DataResponse
 	 */
-	protected function createOneToOneRoom(string $targetUserName): DataResponse {
+	protected function createOneToOneRoom(string $targetUserId): DataResponse {
 		$currentUser = $this->userManager->get($this->userId);
 		if (!$currentUser instanceof IUser) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
-		$targetUser = $this->userManager->get($targetUserName);
+		$targetUser = $this->userManager->get($targetUserId);
 		if (!$targetUser instanceof IUser) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
-		if ($this->userId === $targetUserName) {
-			return new DataResponse([], Http::STATUS_FORBIDDEN);
+		try {
+			// We are only doing this manually here to be able to return different status codes
+			// Actually createOneToOneConversation also checks it.
+			$room = $this->manager->getOne2OneRoom($currentUser->getUID(), $targetUser->getUID());
+			$room->ensureOneToOneRoomIsFilled();
+			return new DataResponse(
+				$this->formatRoom($room, $room->getParticipant($currentUser->getUID())),
+				Http::STATUS_OK
+			);
+		} catch (RoomNotFoundException $e) {
 		}
 
-		// If room exists: Reuse that one, otherwise create a new one.
 		try {
-			$room = $this->manager->getOne2OneRoom($this->userId, $targetUser->getUID());
-			$room->ensureOneToOneRoomIsFilled();
-			return new DataResponse($this->formatRoom($room, $room->getParticipant($currentUser->getUID())), Http::STATUS_OK);
+			$room = $this->roomService->createOneToOneConversation($currentUser, $targetUser);
+			return new DataResponse(
+				$this->formatRoom($room, $room->getParticipant($currentUser->getUID())),
+				Http::STATUS_CREATED
+			);
+		} catch (InvalidArgumentException $e) {
+			// Same current and target user
+			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		} catch (RoomNotFoundException $e) {
-			$room = $this->manager->createOne2OneRoom();
-			$room->addUsers([
-				'userId' => $currentUser->getUID(),
-				'participantType' => Participant::OWNER,
-			], [
-				'userId' => $targetUser->getUID(),
-				'participantType' => Participant::OWNER,
-			]);
-
-			return new DataResponse($this->formatRoom($room, $room->getParticipant($currentUser->getUID())), Http::STATUS_CREATED);
+			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		}
 	}
 
@@ -627,23 +665,19 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	protected function createGroupRoom(string $targetGroupName): DataResponse {
-		$targetGroup = $this->groupManager->get($targetGroupName);
 		$currentUser = $this->userManager->get($this->userId);
-
-		if (!$targetGroup instanceof IGroup) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
-		}
-
 		if (!$currentUser instanceof IUser) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
+		$targetGroup = $this->groupManager->get($targetGroupName);
+		if (!$targetGroup instanceof IGroup) {
+			return new DataResponse([], Http::STATUS_NOT_FOUND);
+		}
+
 		// Create the room
-		$room = $this->manager->createGroupRoom($targetGroup->getGID());
-		$room->addUsers([
-			'userId' => $currentUser->getUID(),
-			'participantType' => Participant::OWNER,
-		]);
+		$name = $this->roomService->prepareConversationName($targetGroup->getDisplayName());
+		$room = $this->roomService->createConversation(Room::GROUP_CALL, $name, $currentUser);
 
 		$usersInGroup = $targetGroup->getUsers();
 		$participants = [];
@@ -676,24 +710,21 @@ class RoomController extends AEnvironmentAwareController {
 			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
 
+		$currentUser = $this->userManager->get($this->userId);
+		if (!$currentUser instanceof IUser) {
+			return new DataResponse([], Http::STATUS_NOT_FOUND);
+		}
+
 		/** @var Circles $circlesApi */
 		try {
 			$circle = Circles::detailsCircle($targetCircleId);
 		} catch (\Exception $e) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
-		$currentUser = $this->userManager->get($this->userId);
-
-		if (!$currentUser instanceof IUser) {
-			return new DataResponse([], Http::STATUS_NOT_FOUND);
-		}
 
 		// Create the room
-		$room = $this->manager->createGroupRoom($circle->getName());
-		$room->addUsers([
-			'userId' => $currentUser->getUID(),
-			'participantType' => Participant::OWNER,
-		]);
+		$name = $this->roomService->prepareConversationName($circle->getName());
+		$room = $this->roomService->createConversation(Room::GROUP_CALL, $name, $currentUser);
 
 		$participants = [];
 		foreach ($circle->getMembers() as $member) {
@@ -731,27 +762,19 @@ class RoomController extends AEnvironmentAwareController {
 	 * @return DataResponse
 	 */
 	protected function createEmptyRoom(string $roomName, bool $public = true): DataResponse {
-		$roomName = trim($roomName);
-		if ($roomName === '') {
-			return new DataResponse([], Http::STATUS_BAD_REQUEST);
-		}
-
 		$currentUser = $this->userManager->get($this->userId);
-
 		if (!$currentUser instanceof IUser) {
 			return new DataResponse([], Http::STATUS_NOT_FOUND);
 		}
 
+		$roomType = $public ? Room::PUBLIC_CALL : Room::GROUP_CALL;
+
 		// Create the room
-		if ($public) {
-			$room = $this->manager->createPublicRoom($roomName);
-		} else {
-			$room = $this->manager->createGroupRoom($roomName);
+		try {
+			$room = $this->roomService->createConversation($roomType, $roomName, $currentUser);
+		} catch (InvalidArgumentException $e) {
+			return new DataResponse([], Http::STATUS_BAD_REQUEST);
 		}
-		$room->addUsers([
-			'userId' => $currentUser->getUID(),
-			'participantType' => Participant::OWNER,
-		]);
 
 		return new DataResponse($this->formatRoom($room, $room->getParticipant($currentUser->getUID())), Http::STATUS_CREATED);
 	}
@@ -836,16 +859,27 @@ class RoomController extends AEnvironmentAwareController {
 	 * @RequireParticipant
 	 * @RequireModeratorOrNoLobby
 	 *
+	 * @param bool $includeStatus
 	 * @return DataResponse
 	 */
-	public function getParticipants(): DataResponse {
+	public function getParticipants(bool $includeStatus = false): DataResponse {
 		if ($this->participant->getParticipantType() === Participant::GUEST) {
 			return new DataResponse([], Http::STATUS_FORBIDDEN);
 		}
 
 		$maxPingAge = $this->timeFactory->getTime() - 100;
 		$participants = $this->room->getParticipantsLegacy();
-		$results = [];
+		$results = $headers = $statuses = [];
+
+		if ($this->userId !== null
+			&& $includeStatus
+			&& count($participants['users']) < 100
+			&& $this->appManager->isEnabledForUser('user_status')) {
+			$userIds = array_map('strval', array_keys($participants['users']));
+			$statuses = $this->statusManager->getUserStatuses($userIds);
+
+			$headers['X-Nextcloud-Has-User-Statuses'] = true;
+		}
 
 		foreach ($participants['users'] as $userId => $participant) {
 			$userId = (string) $userId;
@@ -858,10 +892,17 @@ class RoomController extends AEnvironmentAwareController {
 				continue;
 			}
 
-			$results[] = array_merge($participant, [
-				'userId' => $userId,
-				'displayName' => (string) $user->getDisplayName(),
-			]);
+			$participant['userId'] = $userId;
+			$participant['displayName'] = (string) $user->getDisplayName();
+
+			if (isset($statuses[$userId])) {
+				$participant['status'] = $statuses[$userId]->getStatus();
+				$participant['statusIcon'] = $statuses[$userId]->getIcon();
+				$participant['statusMessage'] = $statuses[$userId]->getMessage();
+				$participant['statusClearAt'] = $statuses[$userId]->getClearAt();
+			}
+
+			$results[] = $participant;
 		}
 
 		$guestSessions = [];
@@ -887,7 +928,7 @@ class RoomController extends AEnvironmentAwareController {
 			$this->room->cleanGuestParticipants();
 		}
 
-		return new DataResponse($results);
+		return new DataResponse($results, Http::STATUS_OK, $headers);
 	}
 
 	/**
