@@ -183,6 +183,9 @@ class SignalingController extends OCSController {
 		try {
 			$response = $client->get($url . '/api/v1/welcome', [
 				'verify' => (bool) $signalingServers[$serverId]['verify'],
+				'nextcloud' => [
+					'allow_local_address' => true,
+				],
 			]);
 
 			$body = $response->getBody();
@@ -502,7 +505,7 @@ class SignalingController extends OCSController {
 		$action = !empty($roomRequest['action']) ? $roomRequest['action'] : 'join';
 
 		try {
-			$room = $this->manager->getRoomByToken($roomId);
+			$room = $this->manager->getRoomByToken($roomId, $userId);
 		} catch (RoomNotFoundException $e) {
 			return new DataResponse([
 				'type' => 'error',
