@@ -28,13 +28,11 @@ use OCA\Talk\Events\JoinRoomUserEvent;
 use OCA\Talk\Events\RoomEvent;
 use OCA\Talk\Room;
 use OCP\AppFramework\Utility\ITimeFactory;
-use OCP\EventDispatcher\Event;
 use OCP\EventDispatcher\IEventDispatcher;
-use OCP\Notification\IApp;
 use OCP\Notification\IManager;
-use OCP\ILogger;
 use OCP\IUser;
 use OCP\IUserSession;
+use Psr\Log\LoggerInterface;
 
 class Listener {
 
@@ -46,7 +44,7 @@ class Listener {
 	protected $userSession;
 	/** @var ITimeFactory */
 	protected $timeFactory;
-	/** @var ILogger */
+	/** @var LoggerInterface */
 	protected $logger;
 
 	/** @var bool */
@@ -56,7 +54,7 @@ class Listener {
 								IEventDispatcher $dispatcher,
 								IUserSession $userSession,
 								ITimeFactory $timeFactory,
-								ILogger $logger) {
+								LoggerInterface $logger) {
 		$this->notificationManager = $notificationManager;
 		$this->dispatcher = $dispatcher;
 		$this->userSession = $userSession;
@@ -121,6 +119,7 @@ class Listener {
 		$actorId = $actor->getUID();
 
 		$notification = $this->notificationManager->createNotification();
+		$shouldFlush = $this->notificationManager->defer();
 		$dateTime = $this->timeFactory->getDateTime();
 		try {
 			$notification->setApp('spreed')
@@ -130,7 +129,10 @@ class Listener {
 					'actorId' => $actor->getUID(),
 				]);
 		} catch (\InvalidArgumentException $e) {
-			$this->logger->logException($e, ['app' => 'spreed']);
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
+			if ($shouldFlush) {
+				$this->notificationManager->flush();
+			}
 			return;
 		}
 
@@ -144,9 +146,13 @@ class Listener {
 				$notification->setUser($participant['userId']);
 				$this->notificationManager->notify($notification);
 			} catch (\InvalidArgumentException $e) {
-				$this->logger->logException($e, ['app' => 'spreed']);
+				$this->logger->error($e->getMessage(), ['exception' => $e]);
 			}
 		}
+
+		if ($shouldFlush) {
+			$this->notificationManager->flush();
+		}
 	}
 
 	/**
@@ -168,7 +174,7 @@ class Listener {
 				->setSubject('invitation');
 			$this->notificationManager->markProcessed($notification);
 		} catch (\InvalidArgumentException $e) {
-			$this->logger->logException($e, ['app' => 'spreed']);
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
 			return;
 		}
 	}
@@ -206,8 +212,8 @@ class Listener {
 		$actor = $this->userSession->getUser();
 		$actorId = $actor instanceof IUser ? $actor->getUID() :'';
 
-		$this->dispatcher->dispatch(IApp::class . '::defer', new Event());
 		$notification = $this->notificationManager->createNotification();
+		$shouldFlush = $this->notificationManager->defer();
 		$dateTime = $this->timeFactory->getDateTime();
 		try {
 			// Remove all old notifications for this room
@@ -223,8 +229,10 @@ class Listener {
 			])
 				->setDateTime($dateTime);
 		} catch (\InvalidArgumentException $e) {
-			$this->logger->logException($e, ['app' => 'spreed']);
-			$this->dispatcher->dispatch(IApp::class . '::flush', new Event());
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
+			if ($shouldFlush) {
+				$this->notificationManager->flush();
+			}
 			return;
 		}
 
@@ -238,10 +246,13 @@ class Listener {
 				$notification->setUser($userId);
 				$this->notificationManager->notify($notification);
 			} catch (\InvalidArgumentException $e) {
-				$this->logger->logException($e, ['app' => 'spreed']);
+				$this->logger->error($e->getMessage(), ['exception' => $e]);
 			}
 		}
-		$this->dispatcher->dispatch(IApp::class . '::flush', new Event());
+
+		if ($shouldFlush) {
+			$this->notificationManager->flush();
+		}
 	}
 
 	/**
@@ -263,7 +274,7 @@ class Listener {
 				->setSubject('call');
 			$this->notificationManager->markProcessed($notification);
 		} catch (\InvalidArgumentException $e) {
-			$this->logger->logException($e, ['app' => 'spreed']);
+			$this->logger->error($e->getMessage(), ['exception' => $e]);
 			return;
 		}
 	}
