@@ -124,10 +124,11 @@ class Notifier implements INotifier {
 
 	/**
 	 * @param string $objectId
+	 * @param string $userId
 	 * @return Room
 	 * @throws RoomNotFoundException
 	 */
-	protected function getRoom(string $objectId): Room {
+	protected function getRoom(string $objectId, string $userId): Room {
 		if (array_key_exists($objectId, $this->rooms)) {
 			if ($this->rooms[$objectId] === null) {
 				throw new RoomNotFoundException('Room does not exist');
@@ -137,10 +138,16 @@ class Notifier implements INotifier {
 		}
 
 		try {
-			$room = $this->manager->getRoomByToken($objectId);
+			$room = $this->manager->getRoomByToken($objectId, $userId);
 			$this->rooms[$objectId] = $room;
 			return $room;
 		} catch (RoomNotFoundException $e) {
+			if (!is_numeric($objectId)) {
+				// Room does not exist
+				$this->rooms[$objectId] = null;
+				throw $e;
+			}
+
 			try {
 				// Before 3.2.3 the id was passed in notifications
 				$room = $this->manager->getRoomById((int) $objectId);
@@ -201,8 +208,12 @@ class Notifier implements INotifier {
 
 		$l = $this->lFactory->get('spreed', $languageCode);
 
+		if ($notification->getObjectType() === 'hosted-signaling-server') {
+			return $this->parseHostedSignalingServer($notification, $l);
+		}
+
 		try {
-			$room = $this->getRoom($notification->getObjectId());
+			$room = $this->getRoom($notification->getObjectId(), $userId);
 		} catch (RoomNotFoundException $e) {
 			// Room does not exist
 			throw new AlreadyProcessedException();
@@ -687,4 +698,38 @@ class Notifier implements INotifier {
 
 		return $notification;
 	}
+
+	protected function parseHostedSignalingServer(INotification $notification, IL10N $l): INotification {
+		$action = $notification->createAction();
+		$action->setLabel('open_settings')
+			->setParsedLabel($l->t('Open settings'))
+			->setLink($notification->getLink(), IAction::TYPE_WEB)
+			->setPrimary(true);
+
+		switch ($notification->getSubject()) {
+			case 'added':
+				$subject = $l->t('The hosted signaling server is now configured and will be used.');
+				break;
+			case 'removed':
+				$subject = $l->t('The hosted signaling server was removed and will not be used anymore.');
+				break;
+			case 'changed-status':
+				$subject = $l->t('The hosted signaling server account has changed the status from "{oldstatus}" to "{newstatus}".');
+
+				$parameters = $notification->getSubjectParameters();
+				$subject = str_replace(
+					['{oldstatus}', '{newstatus}'],
+					[$parameters['oldstatus'], $parameters['newstatus']],
+					$subject
+				);
+				break;
+			default:
+				throw new \InvalidArgumentException('Unknown subject');
+		}
+
+		return $notification
+			->setParsedSubject($subject)
+			->setIcon($notification->getIcon())
+			->addParsedAction($action);
+	}
 }
